<?php
namespace HellixElementor\Modules\Accordion;

use HellixElementor\Base\Module_Base;
use HellixElementor\Modules\Accordion\Skins;
use Elementor\Plugin as ElementorPlugin;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * The module class.
 */
class Module extends Module_Base {

	/**
	 * Instantiate the object.
	 */
	public function __construct() {
		parent::__construct();
		$this->add_actions();
	}

	/**
	 * Actions in this module.
	 */
	public function add_actions() {
		add_action( 'elementor/widget/accordion/skins_init', [ $this, 'init_skins' ], 10 );
		add_action( 'elementor/element/accordion/section_toggle_style_icon/before_section_end', [ $this, 'add_css_classes_controls' ], 10 );
	}

	/**
	 * Add CSS Classes Controls to the widget.
	 *
	 * @param array $element The elementor widget.
	 */
	public function add_css_classes_controls( $element ) {

		$element->add_responsive_control(
			'icon_size',
			[
				'label'     => esc_html__( 'Size', 'hellix-elementor' ),
				'type'      => Controls_Manager::SLIDER,

				'selectors' => [
					'{{WRAPPER}} .elementor-tab-title .elementor-accordion-icon i:before' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

	}

	/**
	 * Add CSS Classes Controls to the widget.
	 *
	 * @param array $element The elementor widget.
	 */
	public function add_border_controls( $element ) {

		// $element->add_control(
		// 'content_border',
		// [
		// 'label' => esc_html__( 'Content Border', 'elementor' ),
		// 'type' => Controls_Manager::SLIDER,
		// 'selectors' => [
		// '{{WRAPPER}} .elementor-accordion-item' => 'border-width: {{SIZE}}{{UNIT}};',
		// '{{WRAPPER}} .elementor-accordion-item .accordion.-simple .accordion__item' => 'border-width: {{SIZE}}{{UNIT}};',
		// '{{WRAPPER}} .elementor-accordion-item .elementor-tab-title.elementor-active' => 'border-width: {{SIZE}}{{UNIT}};',
		// ],
		// ]
		// );
	}

	/**
	 * Init skins for this module.
	 *
	 * @param Elementor\Widget_Accordion $widget The accordion widget.
	 */
	public function init_skins( $widget ) {
		$widget->add_skin( new Skins\Skin_Accordion_Basic( $widget ) );
	}

	/**
	 * Get the name of the module.
	 *
	 * @return string
	 */
	public function get_name() {
		return 'hx-accordion';
	}

}
