<?php
namespace HellixElementor\Modules\Breadcrumb\Widgets;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use HellixElementor\Base\Base_Widget;


if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * The Widget class.
 */
class Breadcrumb extends Base_Widget {

	/**
	 * Get the name of the widget.
	 *
	 * @return string.
	 */
	public function get_name() {
		return 'hx-breadcrumb';
	}

	/**
	 * Get the title of the widget.
	 *
	 * @return string
	 */
	public function get_title() {
		return __( 'Hellix Breadcrumbs', 'hellix-elementor' );
	}

	/** Get the icon for the widget. */
	public function get_icon() {
		return 'eicon-product-breadcrumbs';
	}

	/**
	 * Keywords for the widget.
	 */
	public function get_keywords() {
		return [ 'shop', 'store', 'breadcrumbs', 'internal links', 'product' ];
	}

	/**
	 * Controls Registered for this widget.
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_breadcrumb',
			[
				'label' => esc_html__( 'Breadcrumb', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'bg_color',
			[
				'label'     => esc_html__( 'Dark Background', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Yes', 'hellix-elementor' ),
				'label_off' => esc_html__( 'No', 'hellix-elementor' ),
				'default'   => 'no',
			]
		);

	}

	/**
	 * Render the widget in the frontend.
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$bg_color = $settings['bg_color'];

		if ( 'yes' === $bg_color ) {
			$style = 'light';
		} else {
			$style = 'dark';
		}
		$args = [ 'style' => $style ];
		hellix_breadcrumb( $args );
	}

	/**
	 * Render the Plain content.
	 */
	public function render_plain_content() {}
}

