<?php
namespace HellixElementor\Modules\Carousel\Skins;

use Elementor;
use Elementor\Skin_Base;
use Elementor\Control_Media;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Controls_Manager;
use HellixElementor\Core\Utils as AR_Utils;
use Elementor\Icons_Manager;
use Elementor\Widget_Base;
use Elementor\Group_Control_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Skin for Hero Style 3.
 */
class Hero_Style_3 extends Skin_Base {

	/**
	 * Get the name of the widget.
	 *
	 * @return string
	 */
	public function get_id() {
		return 'hero-caorusel-3';
	}

	/**
	 * Get the title of the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Hero Carousel 3', 'hellix-elementor' );
	}

	/**
	 * Print Slider
	 *
	 * @param  array $settings The Widget settings.
	 *
	 * @return void
	 */
	protected function print_slider( array $settings = null ) {

		$widget = $this->parent;
		$count  = 1;

		if ( null === $settings ) {
			$settings = $widget->get_settings_for_display();
		}

		$widget->add_render_attribute(
			'mainSlider',
			array(
				'class' => 'mainSlider -type-3 swiper-container js-mainSlider-type-3',
			)
		); ?>

		<section <?php $widget->print_render_attribute_string( 'mainSlider' ); ?>>
			<div class="swiper-wrapper">
				<?php foreach ( $settings['slides'] as $slide ) : ?>

					<?php
					$this->print_slide( $slide, $settings, 'image-slide-' . $slide['_id'], $count );
					$count ++;
					?>

				<?php endforeach; ?>
			</div>
			<?php if ( 'yes' == $settings['show_dots'] ) { ?>
				<div class="pagination -slider -white js-pagination"></div>
			<?php } ?>
			<?php if ( 'yes' == $settings['show_arrows'] ) { ?>
				<?php $this->render_navigation(); ?>
			<?php } ?>
			
		</section>
		<?php
	}

	/**
	 * Print the slide.
	 *
	 * @param  array $slide    The slide information.
	 * @param  array $settings The widget settings.
	 * @param  int   $index    The slide number.
	 * @param  int   $count    The loop count.
	 * @return void
	 */
	protected function print_slide( array $slide, array $settings, $index, $count ) {

		$widget = $this->parent;

		?>
		<div class="swiper-slide">
			<div data-parallax="0.6" class="mainSlider__image" data-swiper-parallax="40%">
				<?php echo wp_kses_post( $widget->get_slide_image_html( $slide, $index ) ); ?>
			</div>

			<div class="container">
				<div class="row align-items-center">
					<div class="col-12">
						<div class="mainSlider__content js-content">
							<div class="row">
								<div class="col-xl-7 col-lg-9 offset-lg-1 col-md-11">
									<?php
									if ( 1 === $count ) {
										$widget->add_render_attribute( 'data-attr-' . $index, 'data-anim', 'split-lines' );
									}
									$widget->add_render_attribute( 'data-attr-' . $index, 'data-split', 'lines' );
									$widget->add_render_attribute( 'data-attr-' . $index, 'class', 'js-title-wrap' );
									?>
									<div <?php $widget->print_render_attribute_string( 'data-attr-' . $index ); ?>>
										<?php $this->render_title( $settings, $slide, $index ); ?>
									</div>
									<?php $this->render_button( $slide, $settings, $index ); ?>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		<?php
	}

	/**
	 * Render the title of the slide.
	 *
	 * @param  array $settings The Widget settings.
	 * @param  array $slide    The slide information.
	 * @param  int   $i        Index of the slide.
	 * @return void
	 */
	public function render_title( $settings, $slide, $i ) {
		$widget = $this->parent;
		$widget->add_render_attribute(
			'title_css' . $i,
			'class',
			[
				'hx-hero__title',
				'mainSlider__title',
				'uppercase',
				'js-title ' . $settings['title_css'],
			]
		);

		$tag = $settings['title_tag'];

		?>
		<<?php echo esc_attr( $tag ); ?> <?php $widget->print_render_attribute_string( 'title_css' . $i ); ?>>
			<?php echo wp_kses_post( $slide['title'] ); ?>
		</<?php echo esc_attr( $tag ); ?>> 
		<?php
	}

	/**
	 * Render Navigation
	 */
	public function render_navigation() {

		$widget = $this->parent;

		$widget->add_render_attribute(
			'controls',
			array(
				'class' => 'pagination_color__title navigation -slider -white js-navigation',
			)
		);

		$widget->add_render_attribute(
			'prev',
			array(
				'class' => 'pagination_color__title navigation__item js-nav-prev',
			)
		);

		$widget->add_render_attribute(
			'next',
			array(
				'class' => 'navigation__item js-nav-next pagination_color__title',
			)
		);

		$widget->add_render_attribute(
			'icon-left',
			array(
				'class' => 'icon icon-left-arrow',
			)
		);

		$widget->add_render_attribute(
			'icon-right',
			array(
				'class' => 'icon icon-right-arrow',
			)
		);
		?>

		<div <?php $widget->print_render_attribute_string( 'controls' ); ?>>
			<div <?php $widget->print_render_attribute_string( 'prev' ); ?>>
				<i <?php $widget->print_render_attribute_string( 'icon-left' ); ?>></i>
			</div>
			<div <?php $widget->print_render_attribute_string( 'next' ); ?>> 
				<i <?php $widget->print_render_attribute_string( 'icon-right' ); ?>></i>
			</div>
		</div>
		<?php

	}

	/**
	 * Render Button.
	 *
	 * @param  array $slide    The slide information.
	 * @param  array $settings The Widget settings.
	 * @param  int   $index    The slide index.
	 */
	public function render_button( $slide, $settings, $index ) {

		$widget         = $this->parent;
		$class_btn      = 'button-pulse__btn button-color bg-beige-dark mr-24 bg-' . $settings['button_type'];
		$btn_link_class = 'mainSlider__button mt-24 js-button';

		$widget->add_render_attribute( 'button-' . $index, 'class', $class_btn );
		$widget->add_render_attribute( 'button-link-' . $index, 'class', $btn_link_class );
		if ( ! empty( $slide['btn_link']['url'] ) ) {
			$widget->add_link_attributes( 'button-link-' . $index, $slide['btn_link'] );
		}

		?>

		<a <?php $widget->print_render_attribute_string( 'button-link-' . $index ); ?>>
			<div class="button-pulse">
				<span <?php $widget->print_render_attribute_string( 'button-' . $index ); ?>>
					<i class="icon text-white" data-feather="play"></i>
				</span>
			</div>
			<div class="text button__text_color uppercase fw-600 text-sm">
				<?php echo esc_html( $slide['btn_text'] ); ?>
			</div>
		</a>
		<?php
	}

	/**
	 * Render the widget in the frontend.
	 */
	public function render() {
		$widget  = $this->parent;
		$hero_v3 = uniqid( 'hero-v2-' );
		$widget->add_render_attribute( 'mainSlider', 'id', $hero_v3 );
		$settings = $widget->get_settings_for_display();
		$this->print_slider( $settings );
		$this->render_script( $hero_v3 );
	}

	/**
	 * Render script in the editor.
	 *
	 * @param string $hero_v3 passing id.
	 */
	public function render_script( $hero_v3 ) {
		if ( Elementor\Plugin::$instance->editor->is_edit_mode() ) :
			?>
			<script type="text/javascript">
				/**
				 * Editor Slider Load.
				 */
				var MainSlider3 = (function() {
						let sliderInstance;
						let currentIndex = 0;

						function sliderInit() {
							const slider = document.querySelector('#<?php echo esc_attr( $hero_v3 ); ?>');
							if (!slider) return;

							sliderInstance = new Swiper(slider, {
							spaceBetween: 0,
							speed: 1000,
							parallax: true,
							lazy: {
								loadPrevNext: true,
							},
							breakpoints: {
								575: {
								parallax: false,
								},
							},
							navigation: {
								prevEl: slider.querySelector('.js-nav-prev'),
								nextEl: slider.querySelector('.js-nav-next'),
							},
							pagination: {
								el: slider.querySelector('.js-pagination'),
								bulletClass: 'pagination__item',
								bulletActiveClass: 'is-active',
								bulletElement: 'div',
								clickable: true
							},
							});
						}

						function sliderEvents() {
							sliderInstance.on('slideChangeTransitionEnd', function () {
							hideContent(sliderInstance.slides[currentIndex]);
							showContent(sliderInstance.slides[sliderInstance.activeIndex]);
							currentIndex = sliderInstance.activeIndex;
							});
						}

						function hideContent(slide) {
							const lines = slide.querySelectorAll('.js-title .split__line')
							const text = slide.querySelector('.js-text')
							const button = slide.querySelector('.js-button')

							gsap.timeline()
							.set(lines, {
								y: '100%',
							})
							.set(text, {
								opacity: 0,
								y: '30px',
							})
							.set(button, {
								opacity: 0,
								y: '30px',
							});
						}

						function showContent(slide) {
							const lines = slide.querySelectorAll('.js-title .split__line')
							const text = slide.querySelector('.js-text')
							const button = slide.querySelector('.js-button')

							gsap.timeline()
							.to(lines, {
								stagger: 0.1,
								duration: 0.9,
								ease: 'power3.out',
								y: '0%',
							})
							.to(button, {
								duration: 0.6,
								ease: 'power3.out',
								opacity: 1,
								y: '0%',
							}, ">-0.4");
						}

						function hideSlides() {
							const slider = document.querySelector('#<?php echo esc_attr( $hero_v3 ); ?>');
							if (!slider) return;
							const lines = slider.querySelectorAll('.js-title .split__line')
							const text = slider.querySelectorAll('.js-text')
							const button = slider.querySelectorAll('.js-button')

							gsap.timeline()
							.set(lines, {
								y: '100%',
							})
							.set(button, {
								opacity: 0,
								y: '30px',
							});
						}

						function init() {
							const target = document.querySelector('#<?php echo esc_attr( $hero_v3 ); ?>');
							if (!target) return;
							sliderInit();
							hideSlides();
							sliderEvents();
						}

						return {
							init: init,
						}
						})();
					MainSlider3.init();
			</script>
			<?php
		endif;
	}

}
