<?php
namespace HellixElementor\Modules\Carousel\Skins;

use Elementor;
use Elementor\Skin_Base;
use Elementor\Control_Media;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Controls_Manager;
use HellixElementor\Core\Utils as HX_Utils;
use Elementor\Icons_Manager;
use Elementor\Widget_Base;
use Elementor\Group_Control_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Repeater;
use Elementor\Plugin;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Skin for Hero Style 1.
 */
class Hero_Style_4 extends Skin_Base {

	/**
	 * Get the name of the widget.
	 *
	 * @return string
	 */
	public function get_id() {
		return 'hero-caorusel-4';
	}

	/**
	 * Get the title of the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Hero Carousel 4', 'hellix-elementor' );
	}

	/**
	 * Register Controls Action.
	 */
	protected function _register_controls_actions() {
		add_action( 'elementor/element/hx-hero-carousel/section_slides/after_section_end', [ $this, 'add_controls' ], 10 );
		add_action( 'elementor/element/hx-hero-carousel/section_pagination_style/after_section_end', [ $this, 'add_style_controls' ], 10 );
	}

	/**
	 * Update controls for removing column and caption controls.
	 *
	 * @param Elementor\Widget_Base $widget The widget settings.
	 */
	public function add_style_controls( $widget ) {

		$this->parent->start_injection(
			[
				'at' => 'after',
				'of' => 'pagination_label',
			]
		);

		$this->add_control(
			'pagination_label_prev',
			[
				'label'   => esc_html__( 'Prev Text', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( 'PREVIOUS PROJECT', 'hellix-elementor' ),
			]
		);

		$this->parent->end_injection();
	}
	/**
	 * Update controls for removing column and caption controls.
	 *
	 * @param Elementor\Widget_Base $widget The widget settings.
	 */
	public function add_controls( $widget ) {
		$this->parent = $widget;
		$this->start_controls_section(
			'section_style_icon',
			[
				'label' => esc_html__( 'Icon', 'hellix-elementor' ),

			]
		);

		$this->add_control(
			'social_list',
			[
				'label'       => esc_html__( 'Icon List', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'link|value', 'hellix-elementor' ),
				'default'     => esc_html__( 'https://facebook.com', 'hellix-elementor' ),
				'description' => esc_html__( 'Enter the social profiles here. Each profile URL should be separated by a new line by hitting Enter button', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'social_icon_color',
			[
				'label'     => esc_html__( 'Social Icon Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hx-hero_carousel__icon' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'enable_attribute',
			[
				'type'      => Controls_Manager::SWITCHER,
				'label'     => esc_html__( 'Enable Attributes?', 'hellix-elementor' ),
				'default'   => 'no',
				'label_off' => esc_html__( 'Show', 'hellix-elementor' ),
				'label_on'  => esc_html__( 'Hide', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'attribute_list',
			[
				'label'       => esc_html__( 'Attribute', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'link|value', 'hellix-elementor' ),
				'default'     => esc_html__( 'https://gmail.com|hello@hellix.com', 'hellix-elementor' ),
				'description' => esc_html__( 'Enter the Attributes here. Each profile URL should be separated by a new line by hitting Enter button', 'hellix-elementor' ),
				'condition'   => [
					$this->get_control_id( 'enable_attribute' ) => 'yes',
				],
			]
		);

		$this->end_controls_section();
	}
	/**
	 * Print slider.
	 *
	 * @param  array|null $settings The widget settings.
	 * @return void
	 */
	protected function print_slider( array $settings = null ) {

		$widget = $this->parent;
		$count  = 1;

		if ( null === $settings ) {
			$settings = $widget->get_settings_for_display();
		}

		$widget->add_render_attribute(
			'mainSlider',
			array(
				'class' => 'mainSlider -type-4 swiper-container js-mainSlider-type-4',
			)
		); ?>

		<section <?php $widget->print_render_attribute_string( 'mainSlider' ); ?>>
			<div class="mainSlider__lines"></div>
			<div class="swiper-wrapper">
				<?php foreach ( $settings['slides'] as $slide ) : ?>
					<?php
					$this->print_slide( $slide, $settings, 'image-slide-' . $slide['_id'], $count );
					$count ++;
					?>
				<?php endforeach; ?>
			</div>
			<?php if ( 'yes' === $settings['show_arrows'] ) { ?>
				<?php $this->render_navigation( $settings ); ?>
			<?php } ?>

			<?php
			$this->render_social_icon();

			$this->render_attribute();
			?>
		</section>
		<?php
	}

	/**
	 * Render social icon.
	 */
	public function render_social_icon() {
		$widget = $this->parent;
		$widget->add_render_attribute( 'profile_icons_wrapper', 'class', 'mainSlider__socials_item' );
		if ( ! Plugin::$instance->editor->is_edit_mode() ) {
			$widget->add_render_attribute( 'profile_icons_wrapper', 'data-anim-child', 'slide-up' );
		}
		?>
		<div class="mainSlider__socials js-socials md:d-none">
			<div <?php $widget->print_render_attribute_string( 'profile_icons_wrapper' ); ?>>
				<?php
				$this->render_profile_icons();
				?>
			</div>
		</div>
		<?php
	}

	/**
	 * Render Attributes.
	 */
	public function render_attribute() {
		$widget   = $this->parent;
		$settings = $widget->get_settings_for_display();

		$skin_control_ids = [
			'enable_attribute',
			'attribute_list',
		];

		$skin_settings = [];

		foreach ( $skin_control_ids as $skin_control_id ) {
			$skin_settings[ $skin_control_id ] = $this->get_instance_value( $skin_control_id );
		}
		$widget->add_render_attribute( 'icon_wrapper', 'class', 'mainSlider__info md:d-none' );
		if ( ! Plugin::$instance->editor->is_edit_mode() ) {
			$widget->add_render_attribute( 'icon_wrapper', 'data-anim-child', 'slide-up delay-6' );
		}

		$hellix_attribute = $skin_settings['attribute_list'];

		$attributes = explode( "\n", $hellix_attribute );
		if ( $skin_settings['enable_attribute'] ) :
			?>
		<div <?php $widget->print_render_attribute_string( 'icon_wrapper' ); ?>>
			<?php
			foreach ( $attributes as $list ) {
				if ( empty( trim( $list ) ) ) {
					continue;
				}
				$detail = explode( '|', $list );
				if ( ! empty( $detail[0] ) ) :
					$list_url = $detail[0];
					if ( isset( $detail[1] ) ) {
						$list_data = $detail[1];
					}
					?>
					<div class="mainSlider__info__item">
						<i class="mainSlider__info__icon text-white icon-rocket"></i>
						<a data-barba href="<?php echo esc_html( $list_url ); ?>" class="mainSlider__info__text text-white"><?php echo esc_html( $list_data ); ?></a>
					</div>
					<?php
					endif;
			}
			?>
		</div>
			<?php
		endif;
	}

	/**
	 * Get render_profile_icons settings
	 */
	public function render_profile_icons() {
		$widget   = $this->parent;
		$settings = $widget->get_settings_for_display();

		$skin_control_ids = [
			'social_list',
		];

		$skin_settings = [];

		foreach ( $skin_control_ids as $skin_control_id ) {
			$skin_settings[ $skin_control_id ] = $this->get_instance_value( $skin_control_id );
		}

		$hellix_social_icon = $skin_settings['social_list'];

		if ( $hellix_social_icon ) {

			$profiles = explode( "\n", $hellix_social_icon );

			$social_networks = [
				'facebook.com'      => 'facebook',
				'linkedin.com'      => 'linkedin',
				'twitter.com'       => 'twitter',
				'instagram.com'     => 'instagram',
				'github.com'        => 'github',
				'dribbble.com'      => 'dribbble',
				'behance.com'       => 'behance',
				'stackoverflow.com' => 'stack-overflow',

			];

			if ( isset( $profiles ) ) {
				foreach ( $profiles as $social_profile ) {

					if ( empty( trim( $social_profile ) ) ) {
						continue;
					}
					$detail = explode( '|', $social_profile );
					if ( isset( $detail[1] ) ) {
						$class = ' ' . $detail[1];
					}

					$parse = parse_url( $detail[0] );
					$url   = isset( $parse['host'] ) ? $parse['host'] : '';

					if ( isset( $social_networks[ $url ] ) && ! empty( $url ) ) :

						$icon = isset( $class ) ? $social_networks[ $url ] . $class : $social_networks[ $url ];
						?>
					<a data-barba href="<?php echo esc_url( $social_profile ); ?>" class="<?php echo esc_attr( $icon ); ?> text-white">
						<i class="hx-hero_carousel__icon fa fa-<?php echo esc_attr( $social_networks[ $url ] ); ?>" aria-hidden="true"></i>
					</a>
						<?php
					endif;
				}
			}
		}
	}

	/**
	 * Render Navigation
	 *
	 * @param array $settings The widget settings.
	 */
	public function render_navigation( $settings ) {

		$widget   = $this->parent;
		$settings = $widget->get_settings_for_display();

		$skin_control_ids = [
			'pagination_label_prev',
		];

		$skin_settings = [];

		foreach ( $skin_control_ids as $skin_control_id ) {
			$skin_settings[ $skin_control_id ] = $this->get_instance_value( $skin_control_id );
		}
		$widget->add_render_attribute(
			'controls',
			array(
				'class' => 'navigation -slider -white js-navigation',
			)
		);

		$widget->add_render_attribute(
			'prev',
			array(
				'class' => 'navigation__item pagination_color__title js-nav-prev',
			)
		);

		$widget->add_render_attribute(
			'next',
			array(
				'class' => 'navigation__item pagination_color__title js-nav-next',
			)
		);

		$widget->add_render_attribute(
			'icon-left',
			array(
				'class' => 'icon icon-left-arrow',
			)
		);

		$widget->add_render_attribute(
			'icon-right',
			array(
				'class' => 'icon icon-right-arrow',
			)
		);
		?>
		<div <?php $widget->print_render_attribute_string( 'controls' ); ?>>
			<div class="navigation__content">
				<?php
				foreach ( $settings['slides'] as $index => $slide ) :
					$is_active = '';

					if ( 0 === $index ) {
						$is_active = 'is-active';
					}
					$part  = count( $settings['slides'] ) !== $index + 1 ? $index + 1 : $index - 1;
					$label = count( $settings['slides'] ) !== $index + 1 ? $settings['pagination_label'] : $skin_settings['pagination_label_prev'];
					?>
					<div class="navigation__content_item js-navigation-item <?php echo esc_attr( $is_active ); ?>">
						<span class="text-grey hx-hero__pagination_label_color">
							<?php echo esc_html( $label ); ?> 
						</span>
						<div class='pagination_color__title'><?php echo esc_html( $settings['slides'][ $part ]['title'] ); ?></div>
					</div>
				<?php endforeach; ?>
			</div>
			<div <?php $widget->print_render_attribute_string( 'prev' ); ?>>
				<i <?php $widget->print_render_attribute_string( 'icon-left' ); ?>></i>
			</div>
			<div <?php $widget->print_render_attribute_string( 'next' ); ?>> 
				<i <?php $widget->print_render_attribute_string( 'icon-right' ); ?>></i>
			</div>
		</div>
		<?php
	}

	/**
	 * Print Slide.
	 *
	 * @param  array $slide    The slide settings.
	 * @param  array $settings The widget settings.
	 * @param  int   $index    The slide index.
	 * @param  int   $count    The loop count.
	 *
	 * @return void
	 */
	protected function print_slide( array $slide, array $settings, $index, $count ) {

		$widget = $this->parent;
		?>
		<div class="swiper-slide">
			<div data-parallax="0.6" class="mainSlider__image" data-swiper-parallax="40%">
				<?php echo wp_kses_post( $widget->get_slide_image_html( $slide, $index ) ); ?>
			</div>

			<div class="container-fluid h-100">
				<div class="mainSlider__content js-content">
					<div class="row align-items-center md:justify-content-center">
						<div class="col-xl-10 col-lg-11 offset-lg-1 col-sm-9 sm:px-24">
							<?php
							if ( 1 === $count ) {
								$widget->add_render_attribute( 'data-attr-' . $index, 'data-anim', 'split-lines' );
							}
							$widget->add_render_attribute( 'data-attr-' . $index, 'data-split', 'lines' );
							$widget->add_render_attribute( 'data-attr-' . $index, 'class', 'js-title-wrap' );
							?>
							<div <?php $widget->print_render_attribute_string( 'data-attr-' . $index ); ?>>
								<?php $this->render_title( $settings, $slide, $index ); ?>
							</div>
							<div class="col-xl-4 col-lg-6 col-md-8 px-0">
								<div class="mainSlider__text text-white mt-16 js-text">
									<?php $this->render_desc( $settings, $slide, $index ); ?>
								</div>
								<?php $this->render_button( $slide, $settings, $index ); ?>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		<?php
	}

	/**
	 * Render Button.
	 *
	 * @param  array $slide The slide settings.
	 * @param  array $settings The widget settings.
	 * @param  int   $index    The slide index.
	 * @return void
	 */
	public function render_button( $slide, $settings, $index ) {
		$widget    = $this->parent;
		$btn_txt   = $slide['btn_text'];
		$class_btn = 'mainSlider__button button__text_color button mt-20 js-button -' . $settings['button_type'];

		$widget->add_render_attribute( 'button-' . $index, 'class', $class_btn );
		if ( ! empty( $slide['btn_link']['url'] ) ) {
			$widget->add_link_attributes( 'button-' . $index, $slide['btn_link'] );
		}
		?>
		<a <?php $widget->print_render_attribute_string( 'button-' . $index ); ?>> 
			<?php echo esc_html( $btn_txt ); ?>
		</a>
		<?php
	}

	/**
	 * Render title.
	 *
	 * @param  array $settings The widget settings.
	 * @param  array $slide    The slide settings.
	 * @param  int   $i        The slide index.
	 *
	 * @return void
	 */
	public function render_title( $settings, $slide, $i ) {

		$widget = $this->parent;
		$widget->add_render_attribute(
			'title_css' . $i,
			'class',
			[
				'hx-hero__title',
				'mainSlider__title',
				'js-title',
				'text-white ' . $settings['title_css'],
			]
		);

		$tag = $settings['title_tag'];

		?>
		<<?php echo esc_attr( $tag ); ?> <?php $widget->print_render_attribute_string( 'title_css' . $i ); ?>>
			<?php echo wp_kses_post( $slide['title'] ); ?>
		</<?php echo esc_attr( $tag ); ?>>
		<?php
	}

	/**
	 * Render description.
	 *
	 * @param  array $settings The widget settings.
	 * @param  array $slide    The slide settings.
	 * @param  int   $i        The slide index.
	 *
	 * @return void
	 */
	public function render_desc( $settings, $slide, $i ) {

		$widget = $this->parent;
		$widget->add_render_attribute(
			'desc_css' . $i,
			'class',
			[
				'hx-hero__desc_title ',
				$settings['desc_css'],
			]
		);

		?>
		<p <?php $widget->print_render_attribute_string( 'desc_css' . $i ); ?>>
			<?php echo wp_kses_post( $slide['description'] ); ?>
		</p>
		<?php
	}

	/**
	 * Render the widget in the frontend.
	 */
	public function render() {
		$widget   = $this->parent;
		$settings = $widget->get_settings_for_display();
		$this->print_slider( $settings );
		$this->render_script();
	}

	/**
	 * Render script in the editor.
	 */
	public function render_script() {
		if ( Elementor\Plugin::$instance->editor->is_edit_mode() ) :
			?>
			<script type="text/javascript">
				 /**
				 * Editor Slider Load.
				 */
				var MainSlider4 = (function() {
						let sliderInstance;
						let currentIndex = 0;

						function sliderInit() {
							sliderInstance = new Swiper(document.querySelector('.js-mainSlider-type-4'), {
							spaceBetween: 0,
							speed: 1000,
							parallax: true,
							lazy: {
								loadPrevNext: true,
							},
							breakpoints: {
								575: {
								parallax: false,
								},
							},
							navigation: {
								prevEl: document.querySelector('.js-mainSlider-type-4 .js-nav-prev'),
								nextEl: document.querySelector('.js-mainSlider-type-4 .js-nav-next'),
							},
							pagination: {
								el: document.querySelector('.js-mainSlider-type-4 .js-pagination'),
								bulletClass: 'pagination__item',
								bulletActiveClass: 'is-active',
								bulletElement: 'div',
								clickable: true
							},
							});
						}

						function sliderEvents() {
							sliderInstance.on('slideChangeTransitionEnd', function () {
							hideContent(sliderInstance.slides[currentIndex]);
							showContent(sliderInstance.slides[sliderInstance.activeIndex]);
							currentIndex = sliderInstance.activeIndex;
							});
						}

						function hideContent(slide) {
							const lines = slide.querySelectorAll('.js-title .split__line')
							const text = slide.querySelector('.js-text')
							const button = slide.querySelector('.js-button')

							gsap.timeline()
							.set(lines, {
								y: '100%',
							})
							.set(text, {
								opacity: 0,
								y: '30px',
							})
							.set(button, {
								opacity: 0,
								y: '30px',
							});
						}

						function showContent(slide) {
							const lines = slide.querySelectorAll('.js-title .split__line')
							const text = slide.querySelector('.js-text')
							const button = slide.querySelector('.js-button')

							gsap.timeline()
							.to(lines, {
								stagger: 0.1,
								duration: 0.9,
								ease: 'power3.out',
								y: '0%',
							})
							.to(text, {
								duration: 0.6,
								ease: 'power3.out',
								opacity: 1,
								y: '0%',
							}, ">-0.4")
							.to(button, {
								duration: 0.6,
								ease: 'power3.out',
								opacity: 1,
								y: '0%',
							}, ">-0.4");
						}

						function hideSlides() {
							const lines = document.querySelectorAll('.js-mainSlider-type-4 .js-title .split__line')
							const text = document.querySelectorAll('.js-mainSlider-type-4 .js-text')
							const button = document.querySelectorAll('.js-mainSlider-type-4 .js-button')

							gsap.timeline()
							.set(lines, {
								y: '100%',
							})
							.set(text, {
								opacity: 0,
								y: '30px',
							})
							.set(button, {
								opacity: 0,
								y: '30px',
							});
						}

						function pagination() {
							const pagination = document.querySelector('.js-mainSlider-type-4 .js-navigation');
							const items = pagination.querySelectorAll('.js-navigation-item');

							sliderInstance.on('slideChangeTransitionStart', function () {
							pagination.querySelector('.is-active').classList.remove('is-active');
							items[sliderInstance.activeIndex].classList.add('is-active');
							});

							for (let i = 0; i < items.length; i++) {
							const el = items[i];
							
							el.addEventListener('click', (e) => {
								sliderInstance.slideTo(i)
							})
							}
						}

						function init() {
							if (!document.querySelector('.js-mainSlider-type-4')) return;
							sliderInit();
							pagination();
							hideSlides();
							sliderEvents();
						}

						return {
							init: init,
						}
						})();
					MainSlider4.init();
			</script>
			<?php
		endif;
	}
}
