<?php
namespace HellixElementor\Modules\Carousel\Skins;

use Elementor;
use Elementor\Skin_Base;
use Elementor\Control_Media;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Controls_Manager;
use Elementor\Icons_Manager;
use Elementor\Widget_Base;
use Elementor\Repeater;
use HellixElementor\Core\Utils as HXUtils;
use Elementor\Plugin;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Skin for Testimonial Carousel.
 */
class Team_Member_Style_1 extends Skin_Base {

	/**
	 * Get the id for the skin.
	 *
	 * @return string
	 */
	public function get_id() {
		return 'team-member-style-1';
	}

	/**
	 * Get the title for the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Team Member Style 1', 'hellix-elementor' );
	}


	/**
	 * Print Slider.
	 *
	 * @param array $settings THe widget settings.
	 *
	 * @return void
	 */
	protected function print_slider( array $settings = null ) {

		$widget = $this->parent;

		if ( null === $settings ) {
			$settings = $widget->get_settings_for_display();
		}

		$slider_class = array( 'container_class' => 'sectionSlider overflow-hidden layout-pt-sm js-sectionSlider' );
		$gutter       = ! empty( $settings['gutter'] ) ? intval( $settings['gutter']['size'] ) : 30;

		$widget->add_render_attribute(
			'slider',
			array(
				'class'           => $slider_class,
				'data-slider-col' => $widget->get_slick_carousel_options( $settings ),
				'data-gap'        => $gutter,
			)
		);?>
		<div <?php $widget->print_render_attribute_string( 'slider' ); ?> data-pagination>
			<div class="swiper-wrapper">
				<?php
				foreach ( $settings['slides'] as $slide ) :
					$this->print_slide( $slide, $settings, 'image-slide-' . $slide['_id'] );
				endforeach;
				?>
			</div>
			<?php

			if ( 'yes' === $settings['show_arrows'] ) {
				$widget->render_navigation();
			}

			if ( 'yes' === $settings['show_dots'] ) :
				?>
				<div class="pagination -slider mt-48 js-pagination"></div>
				<?php
			endif;
			?>
		</div>
		<?php
	}

	/**
	 * Print Slide.
	 *
	 * @param array $slide    The individual slide.
	 * @param array $settings The Widget settings.
	 * @param int   $index    The slide index.
	 *
	 * @return void
	 */
	public function print_slide( array $slide, array $settings, $index ) {

		$widget = $this->parent;
		$link   = $slide['image']['url'];
		$img    = $settings['image_ratio'];
		?>
		<div class="swiper-slide">
			<div data-anim="img-right cover-black" class="team -zoom-hover">
				<div class="team__image">
					<div class="team__image">
						<?php echo wp_kses_post( HXUtils::render_bg_image( $link, '', $img ) ); ?>
					</div>
					<div class="team__content">
						<?php
						if ( 'yes' === $slide['social_icon'] ) {
							$widget->render_social_icons( $slide );
						}
						?>
					</div>
				</div>
				<div class="mt-20">
					<?php $widget->render_designation( $index, $settings, $slide, 'span' ); ?>
					<?php $widget->render_name( $index, $settings, $slide ); ?>
				</div>
			</div>
		</div>
		<?php
	}

	/**
	 * Render.
	 */
	public function render() {

		$widget   = $this->parent;
		$settings = $widget->get_settings_for_display();
		$this->print_slider( $settings );
		$widget->render_script();

	}

}
