<?php
namespace HellixElementor\Modules\Carousel\Skins;

use Elementor;
use Elementor\Skin_Base;
use Elementor\Control_Media;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Controls_Manager;
use HellixElementor\Core\Utils as HX_Utils;
use Elementor\Icons_Manager;
use Elementor\Widget_Base;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Skin for Testimonial Carousel.
 */
class Testimonial_Style_2 extends Skin_Base {

	/**
	 * Get the id for the skin.
	 *
	 * @return string
	 */
	public function get_id() {
		return 'testimonial-style-2';
	}

	/**
	 * Get the title for the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Testimonial Style 2', 'hellix-elementor' );
	}

	/**
	 * Print Slider.
	 *
	 * @param array $settings THe widget settings.
	 *
	 * @return void
	 */
	protected function print_slider( array $settings = null ) {

		$widget = $this->parent;

		if ( null === $settings ) {
			$settings = $widget->get_settings_for_display();
		}
		$gutter = ! empty( $settings['gutter'] ) ? intval( $settings['gutter']['size'] ) : 30;

		$widget->add_render_attribute(
			'sectionSlider',
			array(
				'class'           => 'overflow-hidden layout-pt-sm js-sectionSlider',
				'data-slider-col' => 'base-3 lg-2 md-2 sm-1',
				'data-gap'        => $gutter,
			)
		);

		$pg_color = ( 'yes' === $settings['border_need'] ) ? '' : '-white';
		?>

		 <div <?php $widget->print_render_attribute_string( 'sectionSlider' ); ?> data-pagination data-loop>
			<div class="swiper-wrapper">
				<?php
				foreach ( $settings['slides'] as $index => $slide ) :
					?>
					<?php $this->print_slide( $slide, $settings, $index ); ?>
				<?php endforeach; ?>
			</div>
			<?php
			if ( 'yes' == $settings['show_arrows'] ) {
				 $this->render_arrow_control();
			}
			?>
			<?php if ( 'yes' == $settings['show_dots'] ) { ?>
				<div class="pagination -slider mt-48 js-pagination <?php echo esc_attr( $pg_color ); ?>"></div>
			<?php } ?>
		</div>
		<?php
	}
	/**
	 * Rendering the Arrow Controls.
	 */
	public function render_arrow_control() {
		?>
		<div class="nav -slider lg:d-none">
			<div data-cursor class="nav__item -left js-prev">
				<i class="icon icon-left-arrow"></i>
			</div>

			<div data-cursor class="nav__item -right js-next">
				<i class="icon icon-right-arrow"></i>
			</div>
		</div>
		<?php
	}

	/**
	 * Render.
	 */
	public function render() {

		$widget   = $this->parent;
		$settings = $widget->get_settings_for_display();
		$this->print_slider( $settings );
		$widget->render_script();
	}

	/**
	 * Render the title of the slide.
	 *
	 * @param  int   $index    Index of the slide.
	 * @param  array $settings The Widget settings.
	 * @param  array $slide    The slide information.
	 * @return void
	 */
	public function render_title( $index, $settings, $slide ) {

		$widget = $this->parent;
		$tag    = $settings['title_tag'];

		$widget->add_render_attribute( 'name_' . $index, 'class', [ 'hx-testimonial__name ' ] );

		if ( ! empty( $settings['name_css'] ) ) {
			$widget->add_render_attribute( 'name_' . $index, 'class', $settings['name_css'] );
		}

		if ( ! empty( $slide['name'] ) ) :
			?>
				<<?php echo esc_attr( $tag ); ?>  <?php $widget->print_render_attribute_string( 'name_' . $index ); ?>>
					<?php echo esc_html( $slide['name'] ); ?> 
				</<?php echo esc_attr( $tag ); ?>>
			<?php
		endif;
	}

	/**
	 * Render the description of the slide.
	 *
	 * @param  int   $index    Index of the slide.
	 * @param  array $settings The Widget settings.
	 * @param  array $slide    The slide information.
	 * @return void
	 */
	public function render_desc( $index, $settings, $slide ) {

		$widget = $this->parent;

		$widget->add_render_attribute( 'desc_' . $index, 'class', [ 'hx-testimonial__content', 'testimonials__comment leading-4xl' ] );
		if ( ! empty( $settings['content_css'] ) ) {
			$widget->add_render_attribute( 'desc_' . $index, 'class', $settings['content_css'] );
		}

		?>
		<p <?php $widget->print_render_attribute_string( 'desc_' . $index ); ?>>
			<?php echo wp_kses_post( $slide['content'] ); ?>
		</p> 
		<?php
	}

	/**
	 * Render the designation of the slide.
	 *
	 * @param  int   $index    Index of the slide.
	 * @param  array $settings The Widget settings.
	 * @param  array $slide    The slide information.
	 * @return void
	 */
	public function render_designation( $index, $settings, $slide ) {

		$widget = $this->parent;

		$widget->add_render_attribute( 'designation_' . $index, 'class', [ 'hx-testimonial__designation' ] );

		if ( ! empty( $settings['designation_css'] ) ) {
			$widget->add_render_attribute( 'designation_' . $index, 'class', $settings['designation_css'] );
		}

		if ( ! empty( $slide['designation'] ) ) :
			?>
			<p  <?php $widget->print_render_attribute_string( 'designation_' . $index ); ?>>
			<?php echo esc_html( $slide['designation'] ); ?> </p>
			<?php
		endif;
	}

	/**
	 * Print Slide.
	 *
	 * @param array $slide    The individual slide.
	 * @param array $settings The Widget settings.
	 * @param int   $index    The slide index.
	 *
	 * @return void
	 */
	protected function print_slide( $slide, array $settings, $index ) {

		$widget = $this->parent;

		if ( ! empty( $slide['image']['url'] ) ) {
			// $link = $slide['image']['url'];
			$widget->add_render_attribute(
				$index . '-image',
				[
					'src'   => $slide['image']['url'],
					'alt'   => ! empty( $slide['name'] ) ? $slide['name'] : '',
					'width' => '56',
				]
			);
		}
		$border_color = ( 'yes' === $settings['border_need'] ) ? 'border-dark' : 'bg-white-10';
		$border_css   = 'border border-color testimonials px-40 py-40 ' . $border_color;
		$widget->add_render_attribute( 'border-css-' . $index, 'class', $border_css );
		?>

		<div class="swiper-slide">
			<div <?php $widget->print_render_attribute_string( 'border-css-' . $index ); ?>>
				<?php $this->render_desc( $index, $settings, $slide ); ?>
				<div class="testimonials__author d-flex align-items-center mt-20">
					<?php if ( $slide['image']['url'] ) : ?>
						<div class="size-xl">
							<?php $widget->render_bg_image( $slide ); ?>
						</div>
					<?php endif; ?>
					<div class="ml-20">
						<?php $this->render_title( $index, $settings, $slide ); ?>
						<?php $this->render_designation( $index, $settings, $slide ); ?>
					</div>
				</div>
			</div>
		</div>
		<?php
	}

}
