<?php
namespace HellixElementor\Modules\Carousel\Widgets;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;
use Elementor\Utils;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Css_Filter;
use Elementor\Group_Control_Image_Size;
use HellixElementor\Modules\QueryControl\Module as Module_Query;
use HellixElementor\Modules\QueryControl\Controls\Group_Control_Related;
use HellixElementor\Core\Utils as HX_Utils;
use HellixElementor\Modules\Carousel\Skins;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Project Carousel.
 */
class Project_Carousel extends Base {
	/**
	 * $query.
	 *
	 * @var null
	 */
	protected $query = null;

	/**
	 * Get the name of the widget.
	 *
	 * @return string
	 */
	public function get_name() {
		return 'hx-project-carousel';
	}

	/**
	 * Get the title of the widget.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Project Carousel', 'hellix-elementor' );
	}

	/** Get the icon for the widget. */
	public function get_icon() {
		return 'eicon-posts-carousel';
	}

	/**
	 * Keywords for the widget.
	 */
	public function get_keywords() {
		return [ 'project-carousel', 'project', 'carousel', 'cpt', 'item', 'loop', 'query', 'cards', 'custom post type' ];
	}

	/**
	 * Set the query variable
	 */
	public function get_query() {
		return $this->query;
	}

	/**
	 * Called on import to override.
	 *
	 * @param array $element The element being imported.
	 */
	public function on_import( $element ) {
		if ( ! get_post_type_object( $element['settings']['posts_post_type'] ) ) {
			$element['settings']['posts_post_type'] = 'post';
		}

		return $element;
	}

	/**
	 * Register the Skins with the widget.
	 *
	 * @return void
	 */
	protected function register_skins() {
		$this->add_skin( new Skins\Project_Style_1( $this ) );
	}

	/**
	 * Add repeater controls
	 *
	 * @param Repeater $repeater Add controls to this repeater.
	 */
	protected function add_repeater_controls( Repeater $repeater ) {}

	/**
	 * Print the slide.
	 *
	 * @param  array $slide         The slide information.
	 * @param  array $settings      The widget settings.
	 * @param  int   $element_key   The slide number.
	 * @return void
	 */
	protected function print_slide( array $slide, array $settings, $element_key ) {}

	/**
	 * Get Repeater Defaults.
	 */
	protected function get_repeater_defaults() {}

	/**
	 * Register controls for this widget.
	 */
	protected function register_controls() {

		$this->register_title_controls();
		$this->register_query_section_controls();

		parent::register_controls();
		$this->remove_control( 'section_slides' );
		$this->remove_control( 'section_additional_options' );
		$this->remove_control( 'section_navigation' );

		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'hellix-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'prj_title_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .portfolioCard__title' => 'color: {{VALUE}} !important;',
				],
				'global'    => [
					'default' => Global_Colors::COLOR_TEXT,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'prj_title_typography',
				'selector' => '{{WRAPPER}} .portfolioCard__title',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_TEXT,
				],
			]
		);

		$this->add_control(
			'prj_title_css',
			[
				'label'       => esc_html__( 'CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => '',
				'description' => esc_html__( 'Applied to project title', 'hellix-elementor' ),

			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_category_style',
			[
				'label' => esc_html__( 'Category', 'hellix-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'cat_name_color',
			[
				'label'     => esc_html__( 'Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .portfolioCard__category' => 'color: {{VALUE}}',
				],
				'global'    => [
					'default' => Global_Colors::COLOR_TEXT,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'category_name_typography',
				'selector' => '{{WRAPPER}} .portfolioCard__category',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_TEXT,
				],
			]
		);

		$this->add_control(
			'category_css',
			[
				'label'       => esc_html__( 'CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => '',
				'description' => esc_html__( 'Applied to project category', 'hellix-elementor' ),

			]
		);

		$this->end_controls_section();
	}

	/**
	 * Set the query variable.
	 *
	 * @param  array $settings The Widget settings.
	 */
	public function query_posts( $settings ) {
		$query_args = [
			'posts_per_page' => $settings['posts_per_page'],
		];

		$elementor_query = Module_Query::instance();
		$this->query     = $elementor_query->get_query( $this, 'posts', $query_args, [] );
	}

	/**
	 * Register Title Controls.
	 */
	protected function register_title_controls() {
		$this->start_controls_section(
			'section_layout',
			[
				'label' => esc_html__( 'Layout', 'hellix-elementor' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'posts_per_page',
			[
				'label'   => __( 'Posts Per Page', 'hellix-elementor' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 1,
				'default' => 3,
			]
		);

		$this->add_control(
			'padding_css',
			[
				'type'      => Controls_Manager::SWITCHER,
				'label'     => esc_html__( 'Enable Padding Top Class', 'hellix-elementor' ),
				'default'   => 'yes',
				'label_off' => esc_html__( 'Hide', 'hellix-elementor' ),
				'label_on'  => esc_html__( 'Show', 'hellix-elementor' ),
				'condition' => [
					'_skin!' => '',
				],
			]
		);

		$this->add_control(
			'show_title',
			[
				'label'     => esc_html__( 'Title', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Show', 'hellix-elementor' ),
				'label_off' => esc_html__( 'Hide', 'hellix-elementor' ),
				'default'   => 'yes',
				'separator' => 'before',
			]
		);

		$this->add_control(
			'title_tag_portfolio',
			[
				'label'     => esc_html__( 'Title HTML Tag', 'hellix-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'h1'   => 'H1',
					'h2'   => 'H2',
					'h3'   => 'H3',
					'h4'   => 'H4',
					'h5'   => 'H5',
					'h6'   => 'H6',
					'div'  => 'div',
					'span' => 'span',
					'p'    => 'p',
				],
				'default'   => 'h3',
				'condition' => [
					'show_title' => 'yes',
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Register Query Section Controls Description.
	 */
	protected function register_query_section_controls() {
		$this->start_controls_section(
			'section_query',
			[
				'label' => esc_html__( 'Query', 'hellix-elementor' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_group_control(
			Group_Control_Related::get_type(),
			[
				'name'      => 'posts',
				'presets'   => [ 'full' ],
				'exclude'   => [
					'posts_per_page', // use the one from Layout section.
				],
				'post_type' => 'jetpack-portfolio',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'prj_section_additional_options',
			[
				'label' => esc_html__( 'Additional Options', 'hellix-elementor' ),
			]
		);

		$prj_slides_per_view = range( 1, 10 );
		$prj_slides_per_view = array_combine( $prj_slides_per_view, $prj_slides_per_view );

		$this->add_responsive_control(
			'prj_slides_per_view',
			[
				'type'      => Controls_Manager::SELECT,
				'label'     => esc_html__( 'Slides Per View', 'hellix-elementor' ),
				'options'   => $prj_slides_per_view,
				'default'   => '1',
				'condition' => [ '_skin!' => 'project-style-1' ],
			]
		);

		$this->add_control(
			'prj_gutter',
			[
				'label'      => esc_html__( 'Gutter Padding', 'hellix-elementor' ),
				'type'       => Controls_Manager::SLIDER,
				'range'      => [
					'px' => [
						'min' => 10,
						'max' => 100,
					],
				],
				'size_units' => [ 'px' ],
				'default'    => [
					'size' => 30,
					'unit' => 'px',
				],
			]
		);

		$this->add_control(
			'prj_data_center',
			[
				'type'      => Controls_Manager::SWITCHER,
				'label'     => esc_html__( 'Data Center', 'hellix-elementor' ),
				'label_off' => esc_html__( 'Hide', 'hellix-elementor' ),
				'label_on'  => esc_html__( 'Show', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'prj_data_loop',
			[
				'type'      => Controls_Manager::SWITCHER,
				'label'     => esc_html__( 'Data Loop', 'hellix-elementor' ),
				'label_off' => esc_html__( 'Hide', 'hellix-elementor' ),
				'label_on'  => esc_html__( 'Show', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'prj_data_pagination',
			[
				'type'      => Controls_Manager::SWITCHER,
				'label'     => esc_html__( 'Data Pagination', 'hellix-elementor' ),
				'label_off' => esc_html__( 'Hide', 'hellix-elementor' ),
				'label_on'  => esc_html__( 'Show', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'prj_data_cursor',
			[
				'type'      => Controls_Manager::SWITCHER,
				'label'     => esc_html__( 'Data Cursor', 'hellix-elementor' ),
				'label_off' => esc_html__( 'Hide', 'hellix-elementor' ),
				'label_on'  => esc_html__( 'Show', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'prj_cursor_label',
			[
				'label'       => esc_html__( 'Text', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'DRAG',
				'description' => esc_html__( 'Text for data cursor label', 'hellix-elementor' ),
				'condition'   => [
					'prj_data_cursor' => 'yes',
				],
			]
		);

		$this->add_control(
			'prj_show_arrows',
			[
				'type'      => Controls_Manager::SWITCHER,
				'label'     => esc_html__( 'Enable Arrows', 'hellix-elementor' ),
				'default'   => 'yes',
				'label_off' => esc_html__( 'Hide', 'hellix-elementor' ),
				'label_on'  => esc_html__( 'Show', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'prj_arrow_color',
			[
				'label'     => esc_html__( 'Arrow Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sectionSlider .nav.-slider .nav__item .icon, .sliderNav__item' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} .sectionSlider .nav.-slider .nav__item' => 'border-color: {{VALUE}}',
				],
				'condition' => [
					'prj_show_arrows' => 'yes',
				],
			]
		);

		$this->add_control(
			'prj_arrow_hover_color',
			[
				'label'     => esc_html__( 'Arrow Hover Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sectionSlider .nav.-slider .nav__item:hover' => 'border-color: {{VALUE}}',
					'{{WRAPPER}} .sectionSlider .nav.-slider .nav__item:hover .icon, .sliderNav__item:hover' => 'color: {{VALUE}} !important;',
				],
				'condition' => [
					'prj_show_arrows' => 'yes',
				],
			]
		);

		$this->add_control(
			'prj_pagination_color',
			[
				'label'     => esc_html__( 'Dot Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pagination.-slider .pagination__item' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .pagination.-slider .pagination__item.is-active::after' => 'border-color: {{VALUE}}',
				],
				'condition' => [
					'prj_show_dots' => 'yes',
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Hellix Portfolio Title Display.
	 *
	 * @param  int $i    The slide number.
	 * @return void
	 */
	protected function hellix_portfolio_title_display( $i ) {

		$settings  = $this->get_settings();
		$title_css = $settings['prj_title_css'];

		$this->add_render_attribute( 'title' . $i, 'class', [ 'portfolioCard__title text-lg fw-600 mt-8 ' . $title_css ] );

		$show_title = $settings['show_title'];
		if ( 'yes' != $show_title ) {
			return;
		}
		$tag = $settings['title_tag_portfolio'];
		?>
	   <<?php echo esc_attr( $tag ); ?> <?php $this->print_render_attribute_string( 'title' . $i ); ?>>
			<?php the_title(); ?>
		</<?php echo esc_attr( $tag ); ?>>
		<?php
	}

	/**
	 * Hellix Portfolio Category Display.
	 *
	 * @param  int $i    The slide number.
	 * @return void
	 */
	protected function hellix_portfolio_category_display( $i ) {

		$settings           = $this->get_settings();
		$portfolio_category = hellix_portfolio_type();
		$category_css       = $settings['category_css'];
		$this->add_render_attribute( 'category' . $i, 'class', [ 'portfolioCard__category text-sm uppercase text-beige-dark ' . $category_css ] );
		?>
		<span <?php $this->print_render_attribute_string( 'category' . $i ); ?>> 
			<?php echo esc_html( $portfolio_category ); ?>
		</span>
		<?php
	}

	/**
	 * Render loop header.
	 */
	protected function render_loop_header() {
		?>
		<div class="swiper-wrapper">
		<?php
	}

	/**
	 * Render loop footer.
	 */
	protected function render_loop_footer() {
		?>
		</div> <!-- / .row -->
		<?php
	}

	/**
	 * Render Arrow Control.
	 */
	public function render_arrow_control() {
		?>
		<div class="nav -slider lg:d-none">
			<div class="nav__item -left js-prev pagination_color__title">
				<i class="icon icon-left-arrow"></i>
			</div>

			<div class="nav__item -right js-next pagination_color__title">
				<i class="icon icon-right-arrow"></i>
			</div>
		</div> 
		<?php
	}

	/**
	 * Get Slick Carousel Options.
	 *
	 * @param  array $settings The Widget settings.
	 */
	public function get_slick_carousel_options( array $settings = null ) {

		$column      = ! empty( $settings['prj_slides_per_view_mobile'] ) ? 'sm-' . intval( $settings['prj_slides_per_view_mobile'] ) : 'sm-1';
		$column_md   = ! empty( $settings['prj_slides_per_view_tablet'] ) ? 'md-' . intval( $settings['prj_slides_per_view_tablet'] ) : 'md-2';
		$column_lg   = ! empty( $settings['prj_slides_per_view'] ) ? 'lg-' . intval( $settings['prj_slides_per_view'] ) : 'lg-4';
		$column_base = ! empty( $settings['prj_slides_per_view'] ) ? 'base-' . intval( $settings['prj_slides_per_view'] ) : 'base-4';

		$default_carousel_args = $column_base . ' ' . $column_lg . ' ' . $column_md . ' ' . $column;

		return $default_carousel_args;
	}

	/**
	 * Print Slider
	 *
	 * @param  array $settings The Widget settings.
	 */
	public function print_slider( $settings ) {

		$this->query_posts( $settings );
		$query = $this->get_query();
		if ( ! $query->found_posts ) {
			return;
		}
		$gutter            = ! empty( $settings['prj_gutter']['size'] ) ? intval( $settings['prj_gutter']['size'] ) : 30;
		$data_cursor_label = '';
		if ( 'yes' === $settings['prj_data_cursor'] ) {
			if ( ! empty( $settings['prj_cursor_label'] ) ) {
				$data_cursor_label = $settings['prj_cursor_label'];
			}
		}

		if ( 'yes' === $settings['prj_data_center'] ) {
			$this->add_render_attribute(
				'sectionSlider',
				'data-center',
				''
			);
		}
		if ( 'yes' === $settings['prj_data_loop'] ) {
			$this->add_render_attribute(
				'sectionSlider',
				'data-loop',
				''
			);
		}
		if ( 'yes' === $settings['prj_data_pagination'] ) {
			$this->add_render_attribute(
				'sectionSlider',
				'data-pagination',
				''
			);
		}
		if ( 'yes' === $settings['prj_data_cursor'] ) {
			$this->add_render_attribute(
				'sectionSlider',
				'data-cursor',
				''
			);
		}
		if ( 'yes' === $settings['prj_data_cursor'] ) {
			$this->add_render_attribute(
				'sectionSlider',
				'data-cursor-label',
				$data_cursor_label
			);
		}
		$this->add_render_attribute(
			'sectionSlider',
			array(
				'class'           => 'sectionSlider overflow-hidden sm:px-16 js-sectionSlider',
				'data-gap'        => $gutter,
				'data-slider-col' => $this->get_slick_carousel_options( $settings ),
			)
		);
		?>
		<div class="row layout-pt-sm">
			<div <?php $this->print_render_attribute_string( 'sectionSlider' ); ?> data-pagination> 
			<?php
				$this->render_loop_header();
				$i = 0;
				// It's the global `wp_query` it self. and the loop was started from the theme.
			if ( $query->in_the_loop ) {
				$this->current_permalink = get_permalink();
				$this->render_project_post( $i );
				$i++;
			} else {
				while ( $query->have_posts() ) {
					$query->the_post();
					$this->current_permalink = get_permalink();
					$this->render_project_post( $i );
					$i++;
				}
			}
				wp_reset_postdata();
				$this->render_loop_footer();
			if ( 'yes' == $settings['prj_show_arrows'] ) {
				$this->render_arrow_control();
			}
			if ( 'yes' == $settings['prj_data_pagination'] ) {
				?>
					<div class="pagination -slider mt-48 js-pagination"></div>
				<?php
			}
			?>
			</div>
		</div> 
		<?php
	}

	/**
	 * Render project post.
	 *
	 * @param  int $index    The slide number.
	 */
	protected function render_project_post( $index ) {
		$this->add_render_attribute(
			'swiper_slide_attr-' . $index,
			array(
				'data-barba' => '',
				'href'       => esc_url( get_permalink() ),
				'class'      => 'portfolioCard -type-1 ratio',
			)
		);
		?>

		<div class="swiper-slide">
			<a <?php $this->print_render_attribute_string( 'swiper_slide_attr-' . $index ); ?>>
				<?php if ( has_post_thumbnail() ) : ?>
					<div class="portfolioCard__image ratio ratio-3:4">
					<?php
						the_post_thumbnail(
							'full',
							[
								'class' => 'h-100 ratio-img js-lazy',
								'alt'   => 'project image',
							]
						);
					?>
											
					</div>
				<?php endif; ?>
				 <div class="portfolioCard__content px-30 py-30">
					<!-- Category -->
					<?php $this->hellix_portfolio_category_display( $index ); ?>
					<!-- Heading -->
					 <?php $this->hellix_portfolio_title_display( $index ); ?>
				</div>
			</a>                    
		</div>
		<?php
	}

	/**
	 * Render the widget in the frontend.
	 */
	public function render() {
		if ( ! class_exists( 'Hellix_Jetpack_Portfolio' ) ) {
			?>
			<div class="alert -warning">
				<div class="alert__content justify-content-center">
					<div class="alert__title text-lg">
						<?php echo esc_html( 'Please enable hellix-extension plugin to view portfolio' ); ?>
					</div>
				</div>
			</div>
			<?php

			return;
		}
		$settings = $this->get_settings_for_display();
		$this->print_slider( $settings );
		$this->render_script();
	}
}
