<?php
namespace HellixElementor\Modules\Carousel\Widgets;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Typography;
use HellixElementor\Modules\Carousel\Skins;
use Elementor\Repeater;
use Elementor\Utils;
use Elementor\Plugin;
use Elementor\Icons_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Testimonials Carousel Hellix Elementor Widget.
 */
class Testimonial_Carousel extends Base {

	/**
	 * $_has_template_content.
	 *
	 * @var boolean
	 */
	protected $_has_template_content = false;

	/**
	 * Print the slide.
	 *
	 * @param  array $slide         The slide information.
	 * @param  array $settings      The widget settings.
	 * @param  int   $element_key   The slide number.
	 * @return void
	 */
	protected function print_slide( array $slide, array $settings, $element_key ) {}

	/**
	 * Get the name of the widget.
	 *
	 * @return string
	 */
	public function get_name() {
		return 'hx-testimonial-carousel';
	}

	/**
	 * Get the title of the widget.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Testimonial Carousel', 'hellix-elementor' );
	}

	/**
	 * Get the icon for the widget.
	 *
	 * @return string
	 */
	public function get_icon() {
		return 'eicon-testimonial-carousel';
	}

	/**
	 * Get the keywords associated with the widget.
	 *
	 * @return array
	 */
	public function get_keywords() {
		return [ 'testimonial', 'carousel', 'image' ];
	}

	/**
	 * Get the group for this widget.
	 *
	 * @return string
	 */
	public function get_group_name() {
		return 'carousel';
	}

	/**
	 * Register the Skins with the widget.
	 *
	 * @return void
	 */
	protected function register_skins() {
		$this->add_skin( new Skins\Testimonial_Style_1( $this ) );
		$this->add_skin( new Skins\Testimonial_Style_2( $this ) );
	}

	/**
	 * Register controls for this widget.
	 */
	protected function register_controls() {
		parent::register_controls();
		$this->remove_control( 'slides_to_scroll' );

		$this->start_injection(
			[
				'of' => 'slides',
			]
		);

		$this->end_injection();

		$this->start_injection(
			[
				'at' => 'before',
				'of' => 'section_navigation',
			]
		);

		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__( 'Content', 'hellix-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'content_color',
			[
				'label'     => esc_html__( 'Content Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hx-testimonial__content' => 'color: {{VALUE}}',
				],
				'global'    => [
					'default' => Global_Colors::COLOR_TEXT,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'content_typography',
				'selector' => '{{WRAPPER}} .hx-testimonial__content',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_TEXT,
				],
			]
		);

		$this->add_control(
			'content_css',
			[
				'label'       => esc_html__( 'CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => '',
				'description' => esc_html__( 'Applied to testimonial content', 'hellix-elementor' ),

			]
		);

		$this->add_control(
			'name_title_style',
			[
				'label'     => esc_html__( 'Name', 'hellix-elementor' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'name_color',
			[
				'label'     => esc_html__( 'Text Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hx-testimonial__name' => 'color: {{VALUE}}',
				],
				'global'    => [
					'default' => Global_Colors::COLOR_TEXT,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'name_typography',
				'selector' => '{{WRAPPER}} .hx-testimonial__name',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
				],
			]
		);

		$this->add_control(
			'name_css',
			[
				'label'       => esc_html__( 'CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => '',
				'description' => esc_html__( 'Applied to testimonial name', 'hellix-elementor' ),

			]
		);

		$this->add_control(
			'heading_title_style',
			[
				'label'     => esc_html__( 'Designation', 'hellix-elementor' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Text Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hx-testimonial__designation' => 'color: {{VALUE}} !important;',
				],
				'global'    => [
					'default' => Global_Colors::COLOR_PRIMARY,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'selector' => '{{WRAPPER}} .hx-testimonial__designation',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_SECONDARY,
				],
			]
		);

		$this->add_control(
			'designation_css',
			[
				'label'       => esc_html__( 'CSS Classes', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'Applied to testimonial designation', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'border_need',
			[
				'label'     => esc_html__( 'Need Border ?', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'default'   => 'no',
				'label_off' => esc_html__( 'Hide', 'hellix-elementor' ),
				'label_on'  => esc_html__( 'Show', 'hellix-elementor' ),
				'condition' => [ '_skin!' => [ 'testimonial-style-1' ] ],

			]
		);

		$this->remove_control( 'section_navigation' );

		$this->end_controls_section();

		$this->end_injection();
	}

	/**
	 * Add repeater controls
	 *
	 * @param Repeater $repeater Add controls to this repeater.
	 */
	protected function add_repeater_controls( Repeater $repeater ) {

		$repeater->add_control(
			'name',
			[
				'label'   => esc_html__( 'Name', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( 'John Doe', 'hellix-elementor' ),
			]
		);

		$repeater->add_control(
			'designation',
			[
				'label'   => esc_html__( 'Designation', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( 'FINANCE MANAGER', 'hellix-elementor' ),
			]
		);

		$repeater->add_control(
			'image',
			[
				'label' => esc_html__( 'Image 1', 'hellix-elementor' ),
				'type'  => Controls_Manager::MEDIA,
			]
		);

		$repeater->add_control(
			'content',
			[
				'label' => esc_html__( 'Content', 'hellix-elementor' ),
				'type'  => Controls_Manager::TEXTAREA,
			]
		);

	}

	/**
	 * Get the default values for the repeater controls
	 */
	protected function get_repeater_defaults() {
		$placeholder_image_src = Utils::get_placeholder_image_src();

		return [
			[
				'content'     => __( '“Ipsum dolor sit amet, consectetur adipiscing elit. hxingilla vel tincidunt ipsum ac.', 'hellix-elementor' ),
				'name'        => __( 'Helena Gibbson', 'hellix-elementor' ),
				'designation' => __( 'FINANCE MANAGER', 'hellix-elementor' ),
				'image'       => [
					'url' => $placeholder_image_src,
				],
			],
			[
				'content'     => __( '“Ipsum dolor sit amet, consectetur adipiscing elit. Fringilla vel tincidunt ipsum ac.', 'hellix-elementor' ),
				'name'        => __( 'Floyd Miles', 'hellix-elementor' ),
				'designation' => __( 'FINANCE MANAGER', 'hellix-elementor' ),
				'image'       => [
					'url' => $placeholder_image_src,
				],
			],
			[
				'content'     => __( '“Ipsum dolor sit amet, consectetur adipiscing elit. Fringilla vel tincidunt ipsum ac.', 'hellix-elementor' ),
				'name'        => __( 'Floyd Miles', 'hellix-elementor' ),
				'designation' => __( 'FINANCE MANAGER', 'hellix-elementor' ),
				'image'       => [
					'url' => $placeholder_image_src,
				],
			],
		];
	}
	/**
	 * Render background image.
	 *
	 * @param array $slide Slide.
	 */
	public function render_bg_image( $slide ) {
		$link              = $slide['image']['url'];
		$img_wrapper_class = 'bg-image rounded-full';
		if ( ! Plugin::$instance->editor->is_edit_mode() ) {
			$img_wrapper_class .= ' swiper-lazy';
			$this->add_render_attribute(
				'edit-bg-image-' . $slide['_id'],
				array(
					'class'           => $img_wrapper_class,
					'data-background' => $link,
				)
			);
			?><div <?php $this->print_render_attribute_string( 'edit-bg-image-' . $slide['_id'] ); ?>></div>
			<?php
		} else {
			$this->add_render_attribute(
				'out-bg-image-' . $slide['_id'],
				array(
					'class' => $img_wrapper_class,
					'style' => 'background-image: url(' . $link . ');',
				)
			);
			?>
			<div <?php $this->print_render_attribute_string( 'out-bg-image-' . $slide['_id'] ); ?>></div>
			<?php
		}
	}
}
