<?php

namespace HellixElementor\Modules\Counter;

use HellixElementor\Base\Module_Base;
use HellixElementor\Modules\Counter\Skins;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * The module class.
 */
class Module extends Module_Base {

	/**
	 * Instantiate the object.
	 */
	public function __construct() {
		parent::__construct();
		$this->add_actions();
	}

	/**
	 * Get the name of the module.
	 *
	 * @return string.
	 */
	public function get_name() {
		return 'override-Counter';
	}

	/**
	 * Actions in this module.
	 */
	public function add_actions() {
		add_action( 'elementor/widget/counter/skins_init', [ $this, 'init_skins' ], 10 );
		add_action( 'elementor/element/counter/section_title/before_section_end', [ $this, 'remove_style_counter_controls' ], 10 );
	}

	/**
	 * Init skins for this module.
	 *
	 * @param Elementor\Widget_Accordion $widget The Counter widget.
	 */
	public function init_skins( $widget ) {
		$widget->add_skin( new Skins\Skin_Counter_Style_1( $widget ) );
	}

	/**
	 * Remove Style Counter Controls.
	 *
	 * @param Elementor\Widget_Counter $widget The Counter widget.
	 */
	public function remove_style_counter_controls( $widget ) {

		$widget->add_control(
			'title_css',
			[
				'label'   => esc_html__( 'Title CSS', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => '',
			]
		);
	}
}
