<?php

namespace HellixElementor\Modules\Counter\Skins;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

use Elementor;
use Elementor\Skin_Base;
use Elementor\Widget_Base;
use Elementor\Icons_Manager;
use Elementor\Controls_Manager;
use Elementor\Plugin;

// Group Controls.
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

// Group Values.
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;

/**
 * Skin for Counter Style 1.
 */
class Skin_Counter_Style_1 extends Skin_Base {

	/**
	 * Get the name of the widget.
	 *
	 * @return string.
	 */
	public function get_id() {
		return 'counter-style-1';
	}

	/**
	 * Get the title of the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Pie Chart - Hellix', 'hellix-elementor' );
	}

	/**
	 * Register Control Actions Here.
	 */
	protected function _register_controls_actions() { //phpcs:ignore PSR2.Methods.MethodDeclaration.Underscore
		add_filter( 'hellix-elementor/widget/counter/print_template', [ $this, 'skin_print_template' ], 10, 2 );
		add_action( 'elementor/element/counter/section_counter/before_section_end', [ $this, 'register_counter_content_controls' ], 10 );
		add_action( 'elementor/element/counter/section_title/after_section_end', [ $this, 'style_counter_controls' ], 10 );
	}

	/**
	 * Register Counter content controls.
	 *
	 * @param array $widget The widget settings.
	 */
	public function register_counter_content_controls( $widget ) {
		$this->parent = $widget;

		$update_control_ids = [ 'prefix', 'suffix', 'duration', 'thousand_separator', 'thousand_separator_char', 'ending_number' ];

		foreach ( $update_control_ids as $update_control_id ) {
			$widget->update_control(
				$update_control_id,
				[
					'condition' => [
						'_skin' => '',
					],
				]
			);
		}

		$this->add_control(
			'pie_ending_number',
			[
				'label'   => esc_html__( 'Ending Number', 'hellix-elementor' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 100,
				'max'     => 100,
				'dynamic' => [
					'active' => true,
				],
			],
			[
				'position' => [
					'at' => 'after',
					'of' => 'starting_number',
				],
			]
		);

		$this->add_control(
			'description',
			[
				'label'       => esc_html__( 'Description', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'     => esc_html__( 'Lorem ipsum dolor amet sociis dolor.', 'hellix-elementor' ),
				'placeholder' => esc_html__( 'Lorem ipsum dolor amet sociis dolor.', 'hellix-elementor' ),
			],
			[
				'position' => [
					'at' => 'after',
					'of' => 'title',
				],
			]
		);
	}

	/**
	 * Style Counter controls.
	 *
	 * @param array $widget The widget settings.
	 */
	public function style_counter_controls( $widget ) {

		$this->start_controls_section(
			'section_description',
			[
				'label' => esc_html__( 'Description', 'hellix-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'desc_color',
			[
				'label'     => esc_html__( 'Description Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'global'    => [
					'default' => Global_Colors::COLOR_SECONDARY,
				],
				'default'   => '#FFFFFF',
				'selectors' => [
					'{{WRAPPER}} .elementor-counter-desc' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'typography_desc',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_SECONDARY,
				],
				'selector' => '{{WRAPPER}} .elementor-counter-desc',
			]
		);

		$this->add_control(
			'desc_css',
			[
				'label'   => esc_html__( 'Description CSS', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => '',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_circle',
			[
				'label' => esc_html__( 'Circle Bar', 'hellix-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'circle_bar_color',
			[
				'label'     => esc_html__( 'Circle Bar Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'global'    => [
					'default' => Global_Colors::COLOR_SECONDARY,
				],
				'selectors' => [
					'{{WRAPPER}} .pieChart circle.pieChart__bar' => 'stroke: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'circle_back_color',
			[
				'label'     => esc_html__( 'Circle back Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'global'    => [
					'default' => Global_Colors::COLOR_SECONDARY,
				],
				'selectors' => [
					'{{WRAPPER}} .pieChart__back' => 'stroke: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget in the frontend.
	 */
	public function render() {

		$widget      = $this->parent;
		$settings    = $widget->get_settings_for_display();
		$description = $this->get_instance_value( 'description' );
		$end_number  = $this->get_instance_value( 'pie_ending_number' );
		$title_css   = $settings['title_css'];
		$desc_css    = $this->get_instance_value( 'desc_css' );
		$widget->add_render_attribute( 'title_css', 'class', [ 'pieChart__title', ' elementor-counter-title', $title_css ] );
		$widget->add_render_attribute( 'description_css', 'class', [ 'pieChart__text', 'elementor-counter-desc', $desc_css ] );
		$widget->add_render_attribute(
			'pieChart-attr',
			[
				'class'        => 'pieChart text-center',
				'data-percent' => $end_number,
				'data-anim'    => 'pie-chart',
			]
		);
		?>
		<div <?php $widget->print_render_attribute_string( 'pieChart-attr' ); ?>>
			<div class="pieChart__chart">
				<svg viewBox="0 0 75 75">
					<circle cx="50%" cy="50%" r="35" class="pieChart__back"></circle>
					<circle cx="50%" cy="50%" r="35" class="pieChart__bar bar-stroke-hidden js-chart-bar"></circle>
				</svg>
				<div class="pieChart__percent elementor-counter-number-wrapper js-chart-percent">0%</div>
			</div>
			<div class="pieChart__content">
				<h4 <?php $widget->print_render_attribute_string( 'title_css' ); ?>>
					<?php echo wp_kses_post( $settings['title'] ); ?>
				</h4>
				<p <?php $widget->print_render_attribute_string( 'description_css' ); ?>>
					<?php echo esc_html( $description ); ?>
				</p>
			</div>
		</div>
		<?php
		$this->render_script();
	}

	/**
	 * Print Template.
	 *
	 * @param string                $content The skin output string.
	 * @param Elementor\Widget_Base $counter The widget.
	 *
	 * @return string
	 */
	public function skin_print_template( $content, $counter ) {

		if ( 'counter' === $counter->get_name() ) {
			return '';
		}

		return $content;
	}

	/**
	 * Render script in the editor.
	 */
	public function render_script() {
		if ( Plugin::$instance->editor->is_edit_mode() ) :
			?>
			<script type="text/javascript">
				
				 /**
				 * Editor Slider Load.
				 */
				var RevealAnim = (function() {
					  function single() {
						const animationTarget = document.querySelectorAll('[data-anim]');
						if (!animationTarget.length) return;

						for (let i = 0; i < animationTarget.length; i++) {
						  const el = animationTarget[i];
						
						  new ScrollMagic.Scene({
							offset: '160px',
							triggerElement: el,
							triggerHook: "onEnter",
							reverse: false,
						  })
						  .on('enter', function (event) {
							animateElement(el);
						  })
						  .addTo(App.SMcontroller)
						}
					}
  
					function animateElement(target) {
						
						let attrVal;
						let animDelay;
						let attrDelayPart;
					  
						if (target.getAttribute('data-anim')) {
						  attrVal = target.getAttribute('data-anim');
						}
					  
						if (attrVal.includes('pie-chart')) {
						  pieChart(target, animDelay);
						}

					}

				  function pieChart(target, animDelay = 0) {
			  
					const counterVal = target.getAttribute('data-percent');
					const chartBar = target.querySelector('.js-chart-bar');
					
					if (counterVal < 0) { counterVal = 0;}
					if (counterVal > 100) { counterVal = 100;}
					
					gsap.fromTo(chartBar, {
					  drawSVG: `0%`,
					}, {
					  delay: 0.3 + animDelay,
					  duration: 1.4,
					  ease: 'power3.inOut',
					  drawSVG: `${counterVal}%`,
				  
					  onStart: () => {
						chartBar.classList.remove('bar-stroke-hidden');
					  }
					});
				  
				  
					let object = { count: 0 };
					const barPercent = target.querySelector('.js-chart-percent');
				  
					gsap.to(object, {
					  count: counterVal,
					  delay: 0.45 + animDelay,
					  duration: 1,
					  ease: 'power3.inOut',
					  
					  onUpdate: function() {
						barPercent.innerHTML = Math.round(object.count) + '%';
					  },
					});
			  
				  }

				  function init() {
					single();
				  }

				  return {
					init: init,
				  }

				})();
				RevealAnim.init();
			</script>
			<?php
		endif;
	}

}
