<?php

namespace HellixElementor\Modules\ImageGallery\Skins;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

use Elementor;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Skin_Base;
use HellixElementor\Plugin;
use Elementor\Group_Control_Border;
use HellixElementor\Core\Utils as HXUtils;

/**
 * Skin for Image Gallery Widget.
 */
class Skin_Style_1 extends Skin_Base {

	/**
	 * Constructor.
	 *
	 * @param Elementor\Widget_Base $parent The widget settings.
	 * @return void
	 */
	public function __construct( Elementor\Widget_Base $parent ) {
		parent::__construct( $parent );
	}

	/**
	 * Get the id of the skin.
	 *
	 * @return string
	 */
	public function get_id() {
		return 'gallery-style-1';
	}

	/**
	 * Get the title of the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Style v1', 'hellix-elementor' );
	}

	/**
	 * Register skin controls actions.
	 */
	protected function _register_controls_actions() {
		parent::_register_controls_actions();

		add_filter( 'elementor/widget/print_template', array( $this, 'skin_print_template' ), 10, 2 );
		add_action( 'elementor/element/image-gallery/section_gallery/before_section_end', [ $this, 'remove_content_controls' ], 10 );
		add_action( 'elementor/element/image-gallery/section_gallery_images/after_section_end', [ $this, 'update_style_controls' ], 10 );
	}

	/**
	 * Remove controls from Content.
	 *
	 * @param Elementor\Widget_Base $widget The Basic gallery widget.
	 */
	public function remove_content_controls( Widget_Base $widget ) {

		$this->parent = $widget;

		$disable_controls = [
			'gallery_rand',
			'gallery_columns',
			'tabs_align_vertical',
			'view',
		];

		foreach ( $disable_controls as $control ) {
			$widget->update_control(
				$control,
				[
					'condition' => [
						'_skin!' => 'gallery-style-1',
					],
				]
			);
		}
	}

	/**
	 * Update controls in Style.
	 *
	 * @param Elementor\Widget_Base $widget The Basic gallery widget.
	 */
	public function update_style_controls( Widget_Base $widget ) {

		$this->parent = $widget;

		$disable_controls = [
			'section_gallery_images',
		];

		foreach ( $disable_controls as $control ) {
			$widget->update_control(
				$control,
				[
					'condition' => [
						'_skin!' => 'gallery-style-1',
					],
				]
			);
		}

		$widget->start_controls_section(
			'section_style',
			[
				'label'     => esc_html__( 'Styles', 'hellix-elementor' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition' => [
					'_skin' => 'gallery-style-1',
				],
			]
		);

		$widget->add_control(
			'row_css',
			[
				'label'     => __( 'Content Wrapper', 'hellix-elementor' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => 'layout-pt-sm',
				'condition' => [
					'_skin' => 'gallery-style-1',
				],
			]
		);

		$widget->end_controls_section();

		$widget->start_controls_section(
			'gallery_border_style',
			[
				'label'     => esc_html__( 'Border', 'hellix-elementor' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition' => [
					'_skin' => 'gallery-style-1',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'      => 'image_border',
				'selector'  => '{{WRAPPER}} .gallery-item .bg-image',
				'separator' => 'before',
			]
		);

		$this->add_control(
			'image_border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'hellix-elementor' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .gallery-item .bg-image' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$widget->end_controls_section();
	}

	/**
	 * Render the skin output.
	 *
	 * @return void
	 */
	public function render() {

		$widget   = $this->parent;
		$settings = $widget->get_settings_for_display();
		$row_css  = $settings['row_css'];
		?>
		<div class="row no-gutters <?php echo esc_attr( $row_css ); ?>">
			<?php
			foreach ( $settings['wp_gallery'] as $count => $slide ) {
				$a_class = [ 'js-gallery', 'instagram__item' ];
				$link    = '#';
				if ( ! isset( $slide['id'] ) && isset( $slide['url'] ) ) {
					$slide['id'] = attachment_url_to_postid( $slide['url'] );
				}
				if ( ! empty( $settings['gallery_link'] ) ) {
					if ( 'none' === $settings['gallery_link'] ) {
						$src = wp_get_attachment_image_src( $slide['id'], $settings['thumbnail_size'], true );
						if ( isset( $src[0] ) ) {
							$link = $src[0];
						}
					} else {
						$link = wp_get_attachment_url( $slide['id'], $settings['thumbnail_size'] );
					}
				} else {
					$link = wp_get_attachment_url( $slide['id'], $settings['thumbnail_size'] );
				}
				if ( 'file' === $settings['gallery_link'] ) {

					if ( 'no' !== $settings['open_lightbox'] ) {
						$widget->add_render_attribute( 'a_link' . $count, 'href', $link );
						$widget->add_render_attribute( 'a_link' . $count, 'class', $a_class );
					} else {
						$widget->add_render_attribute( 'a_link' . $count, 'href', $link );
					}
				} elseif ( 'attachment' === $settings['gallery_link'] ) {
					$widget->add_render_attribute( 'a_link' . $count, 'href', get_attachment_link( $slide['id'] ) );
				}
				$light_box = 'no' !== $settings['open_lightbox'] ? 'yes' : 'no';
				$caption = ! empty( wp_get_attachment_caption( $slide['id'] ) ) ? wp_get_attachment_caption( $slide['id'] ) : '';
				?>
							   
				<div class="col-lg col-6 gallery-item">
					<?php
					if ( 'none' !== $settings['gallery_link'] ) {
						?>
						<a <?php $widget->print_render_attribute_string( 'a_link' . $count ); ?>>
						<?php
					}
					?>
						<div class="instagram__image">
							<?php echo wp_kses_post( HXUtils::render_bg_image( $link, '', '129:112' ) ); ?>
						</div>

						<div class="instagram__content">
							<i class="icon fa fa-instagram" aria-hidden="true"></i>
						</div>
					<?php
					if ( 'none' !== $settings['gallery_link'] ) {
						?>
						</a>
						<?php
					}
					?>
					<?php if ( $caption && 'gallery-style-1' === $settings['_skin'] ) { ?>
					<figcaption class="wp-caption-text gallery-caption"><?php echo esc_html( $caption ); ?></figcaption>
					<?php } ?>
				</div>
			<?php } ?>
		</div> 
		<?php
	}

	/**
	 * Skin Print Template.
	 *
	 * @param string                $content The skin output string.
	 * @param Elementor\Widget_Base $widget The widget.
	 *
	 * @return string
	 */
	public function skin_print_template( $content, $widget ) {
		if ( 'image-gallery' == $widget->get_name() ) {
			return '';
		}
		return $content;
	}
}
