<?php

namespace HellixElementor\Modules\ImageGallery\Skins;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

use Elementor;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Skin_Base;
use HellixElementor\Plugin;

/**
 * Skin for Icon Box Widget.
 */
class Skin_Style_2 extends Skin_Base {

	/**
	 * Get the ID of the skin.
	 *
	 * @return string
	 */
	public function get_id() {
		return 'gallery-style-2';
	}
	/**
	 * Get the title of the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Style v2', 'hellix-elementor' );
	}
	/**
	 * Register skin controls actions.
	 */
	protected function _register_controls_actions() { // phpcs:ignore PSR2.Methods.MethodDeclaration.Underscore
		add_filter( 'elementor/widget/print_template', array( $this, 'skin_print_template' ), 10, 2 );
		add_action( 'elementor/element/image-gallery/section_gallery/after_section_end', [ $this, 'update_controls' ], 10 );
		add_action( 'elementor/element/image-gallery/section_caption/after_section_end', [ $this, 'remove_controls' ], 10 );
		add_action( 'elementor/element/image-gallery/section_gallery_images/after_section_end', [ $this, 'remove_controls_1' ], 10 );
	}

	/**
	 * Update controls for removing column and caption controls.
	 *
	 * @param Elementor\Widget_Base $widget The Basic gallery widget.
	 */
	public function remove_controls_1( $widget ) {
		$this->parent       = $widget;
		$update_control_ids = [ 'section_gallery_images' ];

		foreach ( $update_control_ids as $update_control_id ) {
			$widget->update_control(
				$update_control_id,
				[
					'condition' => [
						'_skin!' => [ 'gallery-style-2', 'gallery-style-1' ],
					],
				]
			);
		}

		$this->start_controls_section(
			'section_style_1',
			[
				'label'     => esc_html__( 'Images', 'hellix-elementor' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition' => [
					'_skin' => 'gallery-style-2',
				],
			]
		);

		$columns_margin  = is_rtl() ? '0 0 -{{SIZE}}{{UNIT}} -{{SIZE}}{{UNIT}};' : '0 -{{SIZE}}{{UNIT}} -{{SIZE}}{{UNIT}} 0;';
		$columns_padding = is_rtl() ? '0 0 {{SIZE}}{{UNIT}} {{SIZE}}{{UNIT}};' : '0 {{SIZE}}{{UNIT}} {{SIZE}}{{UNIT}} 0;';

		$this->add_control(
			'image_spacing_custom',
			[
				'label'      => esc_html__( 'Image Spacing', 'hellix-elementor' ),
				'type'       => Controls_Manager::SLIDER,
				'show_label' => false,
				'range'      => [
					'px' => [
						'max' => 100,
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .hellix-img-item' => 'padding:' . $columns_padding,
					'{{WRAPPER}} .hellix-img'      => 'margin: ' . $columns_margin,
				],
			]
		);

		$this->end_controls_section();
	}
	/**
	 * Update controls for removing column and caption controls.
	 *
	 * @param Elementor\Widget_Base $widget The Basic gallery widget.
	 */
	public function remove_controls( $widget ) {
		$update_control_ids = [ 'section_caption' ];

		foreach ( $update_control_ids as $update_control_id ) {
			$widget->update_control(
				$update_control_id,
				[
					'condition' => [
						'_skin!' => [ 'gallery-style-2' ],
					],
				]
			);
		}
	}

	/**
	 * Update controls for removing column and caption controls.
	 *
	 * @param Elementor\Widget_Base $widget The Basic gallery widget.
	 */
	public function update_controls( $widget ) {
		$update_control_ids = [ 'gallery_rand', 'gallery_columns', 'tabs_align_vertical', 'view' ];

		foreach ( $update_control_ids as $update_control_id ) {
			$widget->update_control(
				$update_control_id,
				[
					'condition' => [
						'_skin!' => [ 'gallery-style-1', 'gallery-style-2' ],
					],
				]
			);
		}

		$this->parent->start_injection(
			[
				'at' => 'after',
				'of' => '_skin',
			]
		);

		$this->parent->add_control(
			'display_style',
			[
				'type'      => Controls_Manager::SELECT,
				'label'     => esc_html__( 'Style Variation', 'hellix-elementor' ),
				'default'   => 'default',
				'options'   => [
					'default'  => esc_html__( 'Style 1', 'hellix-elementor' ),
					'style_v2' => esc_html__( 'Style 2', 'hellix-elementor' ),
				],
				'condition' => [
					'_skin' => 'gallery-style-2',
				],
			]
		);

		$this->parent->end_injection();
	}
	/**
	 * Render.
	 *
	 * @return void
	 */
	public function render() {
		$widget   = $this->parent;
		$settings = $widget->get_settings_for_display();

		$skin_control_ids = [
			'display_style',
		];

		$skin_settings = [];

		foreach ( $skin_control_ids as $skin_control_id ) {
			$skin_settings[ $skin_control_id ] = $this->get_instance_value( $skin_control_id );
		}
		?><div class="row y-gap-32">
			<?php
			foreach ( $settings['wp_gallery'] as $count => $slide ) {

				$a_class = [ 'gallery__item', 'js-gallery', 'hellix-anchor-link' ];
				$link    = '#';
				if ( ! isset( $slide['id'] ) && isset( $slide['url'] ) ) {
					$slide['id'] = attachment_url_to_postid( $slide['url'] );
				}
				if ( $settings['gallery_link'] ) {
					if ( 'none' === $settings['gallery_link'] ) {
						$src = wp_get_attachment_image_src( $slide['id'], $settings['thumbnail_size'], true );
						if ( isset( $src[0] ) ) {
							$link = $src[0];
						}
					} else {
						$link = wp_get_attachment_url( $slide['id'], $settings['thumbnail_size'] );
					}
				} else {
					$link = wp_get_attachment_url( $slide['id'], $settings['thumbnail_size'] );
				}
				$image_class['class'] = 'ratio-img hellix-img-item hellix-img h-100';

				$ratio = [ 'ratio' ];
				if ( 'default' === $settings['display_style'] ) {
					if ( 0 === $count % 3 || 1 === $count % 3 ) :
						$ratio[] = 'ratio-63:60';
					endif;

					if ( 2 === $count % 3 ) :
						$ratio[] = 'ratio-16:9';
					endif;
				} else {
					$ratio[] = 'ratio-63:50';
				}

				$light_box = 'yes' === $settings['open_lightbox'] ? 'yes' : 'no';

				if ( 'none' !== $settings['gallery_link'] ) {
					$widget->add_render_attribute( 'a_link' . $count, 'href', $link );
				}
				$widget->add_render_attribute( 'a_link' . $count, 'class', $a_class );
				$widget->add_render_attribute( 'a_link' . $count, 'data-elementor-open-lightbox', $light_box );
				$widget->add_render_attribute( 'a_link' . $count, [ 'data-gallery' => 'gallery1' ] );

				$widget->add_render_attribute( 'ratio' . $count, 'class', $ratio );

				if ( 'default' === $settings['display_style'] ) {
					if ( 0 === $count % 3 || 1 === $count % 3 ) :
						?>
					<div class="col-lg-6">
						<?php
					endif;
					if ( 2 === $count % 3 ) :
						?>
					<div class="col-12">
						<?php
					endif;

				} else {
					?>
					<div class="col-lg-6">
					<?php
				}
				?>
				<?php
				if ( 'none' !== $settings['gallery_link'] ) {
					?>
					<a <?php $widget->print_render_attribute_string( 'a_link' . $count ); ?>>
					<?php
				}
				?>
						<div <?php $widget->print_render_attribute_string( 'ratio' . $count ); ?>>
						<?php
							$image_html = wp_get_attachment_image( $slide['id'], $settings['thumbnail_size'], false, $image_class );
								echo wp_kses_post( $image_html );
						?>
						</div>
						<div class="gallery__button">
							<i class="icon" data-feather="plus"></i>
						</div>
				<?php
				if ( 'none' !== $settings['gallery_link'] ) {
					?>
					</a>
					<?php
				}
				?>
				</div>
				<?php
			}
			?>
		</div>
		<?php
	}
	/**
	 * Skin_print_template to displaying live preview.
	 *
	 * @param array $content display content.
	 * @param array $widget display content.
	 */
	public function skin_print_template( $content, $widget ) {

		if ( 'image-gallery' === $widget->get_name() ) {
			return '';
		}

		return $content;
	}
}
