<?php
namespace HellixElementor\Modules\Posts\Skins;

use Elementor\Controls_Manager;
use Elementor\Icons_Manager;
use Elementor\Group_Control_Box_Shadow;
use HellixElementor\Modules\Posts\Widgets\Posts_Base;
use HellixElementor\Modules\Posts\Traits\Button_Widget_Trait;
use Elementor\Plugin;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * List Skin class.
 */
class Skin_Post_List extends Skin_Base {

	use Button_Widget_Trait;
	/**
	 * Get the ID of the skin.
	 *
	 * @return string.
	 */
	public function get_id() {
		return 'hellix-posts-list';
	}

	/**
	 * Get the title of the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'List', 'hellix-elementor' );
	}

	/**
	 * Register controls for this widget.
	 *
	 * @return void
	 */
	protected function _register_controls_actions() {
		add_action( 'elementor/element/hx-posts/section_layout/after_section_end', [ $this, 'add_content_controls' ], 20 );

	}

	 /**
	  * Add Controls to Content Tab.
	  *
	  * @return void
	  */
	public function add_content_controls() {

		$this->parent->start_injection(
			[
				'at' => 'after',
				'of' => '_skin',
			]
		);
			$this->add_control(
				'posts_per_page',
				[
					'label'   => esc_html__( 'Posts Per Page', 'hellix-elementor' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 6,
				]
			);

			$this->add_control(
				'wrapper_css',
				[
					'label'   => esc_html__( 'Wrapper CSS', 'hellix-elementor' ),
					'type'    => Controls_Manager::TEXT,
					'default' => esc_html__( 'pr-30 lg:pr-0', 'hellix-elementor' ),

				]
			);

		$this->parent->end_injection();
	}

	/**
	 * Render loop header.
	 */
	protected function render_loop_header() {
		$wrap_css   = array( 'blogSection', 'elementor-posts-container' );
		$wrap_class = $this->get_instance_value( 'wrapper_css' );
		if ( ! empty( $wrap_class ) ) {
			$wrap_css[] = $wrap_class;
		}
		$this->parent->add_render_attribute( 'wrapper-css', 'class', $wrap_css );
		?>
		<div <?php $this->parent->print_render_attribute_string( 'wrapper-css' ); ?>>
		<?php
	}

	/**
	 * Render loop post.
	 */
	public function render_post() {
		get_template_part( 'templates/blog/content', 'list' );
	}

	/**
	 * Render script in the editor.
	 */
	public function render_script() {
		if ( Plugin::$instance->editor->is_edit_mode() ) :
			?>
			<script type="text/javascript">
				/**
				 * Editor Slider Load.
				 */
				function lazyLoading() {
					  if (!document.querySelector('.js-lazy')) {
						return;
					}

					new LazyLoad({
						elements_selector: ".js-lazy",
					});
				}

				lazyLoading();
			</script>
			<?php
		endif;
	}

}
