<?php
namespace HellixElementor\Modules\Progress\Skins;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

use Elementor;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Skin_Base;
use Elementor\Plugin;
use Elementor\Utils;
use Elementor\Skin_Base as Elementor_Skin_Base;

/**
 * Skin for Progress Widget.
 */
class Skin_Style_1 extends Skin_Base {

	/**
	 * Constructor.
	 *
	 * @param Elementor\Widget_Base $parent The widget settings.
	 * @return void
	 */
	public function __construct( Elementor\Widget_Base $parent ) {
		parent::__construct( $parent );
	}

	/**
	 * Get the name of the widget.
	 *
	 * @return string.
	 */
	public function get_id() {
		return 'progress-style-1';
	}

	/**
	 * Get the title of the skin.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Style v1', 'hellix-elementor' );
	}

	/**
	 * Register the control actions.
	 */
	protected function _register_controls_actions() {
		parent::_register_controls_actions();

		add_filter( 'elementor/widget/print_template', array( $this, 'skin_print_template' ), 10, 2 );
		add_action( 'elementor/element/progress/section_progress/before_section_end', [ $this, 'remove_content_controls' ], 10 );
		add_action( 'elementor/element/progress/section_progress_style/after_section_end', [ $this, 'remove_style_controls' ], 10 );
	}

	/**
	 * Remove Content controls.
	 *
	 * @param Widget_Base $widget The widget settings.
	 */
	public function remove_content_controls( Widget_Base $widget ) {

		$this->parent = $widget;

		$disable_controls = [
			'progress_type',
			'display_percentage',
			'inner_text',
		];

		foreach ( $disable_controls as $control ) {
			$widget->update_control(
				$control,
				[
					'condition' => [
						'_skin!' => 'progress-style-1',
					],
				]
			);
		}
	}

	/**
	 * Remove Style controls.
	 *
	 * @param Widget_Base $widget The widget settings.
	 */
	public function remove_style_controls( Widget_Base $widget ) {

		$this->parent = $widget;

		$disable_controls = [
			'section_progress_style',
		];

		foreach ( $disable_controls as $control ) {
			$widget->update_control(
				$control,
				[
					'condition' => [
						'_skin!' => 'progress-style-1',
					],
				]
			);
		}
	}

	/**
	 * Skin Print Template.
	 *
	 * @param string                $content The skin output string.
	 * @param Elementor\Widget_Base $widget The widget.
	 *
	 * @return string
	 */
	public function skin_print_template( $content, $widget ) {
		if ( 'progress' == $widget->get_name() ) {
			return '';
		}
		return $content;
	}

	/**
	 * Render the widget in the frontend.
	 */
	public function render() {

		$widget              = $this->parent;
		$settings            = $widget->get_settings_for_display();
		$progress_percentage = is_numeric( $settings['percent']['size'] ) ? $settings['percent']['size'] : '0';
		if ( 100 < $progress_percentage ) {
			$progress_percentage = 100;
		}

		$widget->add_render_attribute(
			'title',
			[
				'class' => 'elementor-title',
			]
		);

		if ( ! Plugin::$instance->editor->is_edit_mode() ) {
			$widget->add_render_attribute( 'wrapper', 'data-anim-child', 'line-chart' );
		}

		$widget->add_render_attribute(
			'wrapper',
			[
				'class'        => 'lineChart__item',
				'data-percent' => $progress_percentage,
			]
		); ?>

		<div <?php $widget->print_render_attribute_string( 'wrapper' ); ?>>
			<div class="lineChart__content text-black text-sm">
				<?php if ( ! Utils::is_empty( $settings['title'] ) ) { ?>
					<p <?php $widget->print_render_attribute_string( 'title' ); ?>><?php $widget->print_unescaped_setting( 'title' ); ?> 
					</p>
				<?php } ?>
				<p class="lineChart__number number js-number">0</p>
			</div>

			<div class="lineChart-bar">
				<div class="lineChart-bar__bg"></div>
				<div class="lineChart-bar__item bg-black js-bar"></div>
			</div>
		</div>
		<?php
	}

}
