<?php
namespace HellixElementor\Modules\Stat\Widgets;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use HellixElementor\Base\Base_Widget;
use Elementor\Widget_Base;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;


if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * The Widget class.
 */
class Stat extends Base_Widget {

	/**
	 * Get the name of the widget.
	 *
	 * @return string.
	 */
	public function get_name() {
		return 'hx-stat';
	}

	/**
	 * Get the title of the widget.
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( 'Stat', 'hellix-elementor' );
	}

	/** Get the icon for the widget. */
	public function get_icon() {
		return 'eicon-number-field';
	}

	/**
	 * Controls Registered for this widget.
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_stat',
			[
				'label' => esc_html__( 'Stat', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'number',
			[
				'label'   => esc_html__( 'Number', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( '100', 'hellix-elementor' ),
				'dynamic' => [
					'active' => true,
				],
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'hellix-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'default'     => esc_html__( 'Cool Number', 'hellix-elementor' ),
				'placeholder' => esc_html__( 'Cool Number', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'title_size',
			[
				'label'   => esc_html__( 'HTML Tag', 'hellix-elementor' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'h1'    => 'H1',
					'h2'    => 'H2',
					'h3'    => 'H3',
					'h4'    => 'H4',
					'h5'    => 'H5',
					'h6'    => 'H6',
					'div'   => 'div',
					'span'  => 'span',
					'small' => 'small',
					'p'     => 'p',
				],
				'default' => 'h2',
			]
		);

		$this->add_control(
			'light_version',
			[
				'label'     => esc_html__( 'Light Version ?', 'hellix-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Show', 'hellix-elementor' ),
				'label_off' => esc_html__( 'Hide', 'hellix-elementor' ),
				'default'   => 'no',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_number',
			[
				'label' => esc_html__( 'Number', 'hellix-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'wrap_class',
			[
				'label'   => esc_html__( 'Wrap Class', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => '',
			]
		);

		$this->add_control(
			'number_color',
			[
				'label'     => esc_html__( 'Text Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'global'    => [
					'default' => Global_Colors::COLOR_PRIMARY,
				],
				'selectors' => [
					'{{WRAPPER}} .hx-number-wrapper' => 'color: {{VALUE}}!important;',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'typography_number',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
				],
				'selector' => '{{WRAPPER}} .hx-number-wrapper',
			]
		);

		$this->add_control(
			'text_class',
			[
				'label'   => esc_html__( 'Text Class', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => '',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_title',
			[
				'label' => esc_html__( 'Title', 'hellix-elementor' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Text Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'global'    => [
					'default' => Global_Colors::COLOR_SECONDARY,
				],
				'selectors' => [
					'{{WRAPPER}} .hx-stat-title' => 'color: {{VALUE}}!important;',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'typography_title',
				'global'   => [
					'default' => Global_Typography::TYPOGRAPHY_SECONDARY,
				],
				'selector' => '{{WRAPPER}} .hx-stat-title',
			]
		);

		$this->add_control(
			'title_css',
			[
				'label'   => esc_html__( 'Title CSS', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => '',
			]
		);
		$this->end_controls_section();
	}

	/**
	 * Render the widget in the frontend.
	 */
	protected function render() {
		$settings      = $this->get_settings_for_display();
		$light_version = $settings['light_version'];
		$title_css     = $settings['title_css'];
		$text_color    = 'yes' === $light_version ? ' text-white' : ' text-black';
		$light         = 'yes' === $light_version ? ' -light' : '';

		$wrap_class = '';
		if ( ! empty( $settings['wrap_class'] ) ) {
			$wrap_class = $settings['wrap_class'];
		}

		$text_class = '';
		if ( ! empty( $settings['text_class'] ) ) {
			$text_class = $settings['text_class'];
		}

		$this->add_render_attribute( 'counter', 'class', 'counter ' . $wrap_class );
		$this->add_render_attribute( 'title_css', 'class', [ ' hx-stat-title', $title_css, $text_color ] );
		$this->add_render_attribute( 'counter_number', 'class', [ 'hx-number-wrapper', 'counter__number', $text_class, $text_color ] );
		if ( ! empty( $light ) ) {
			$this->add_render_attribute( 'counter', 'class', '-light' );
		}
		?>
		<div <?php $this->print_render_attribute_string( 'counter' ); ?>>
			<div class="counter__back">
				<?php echo esc_html( $settings['number'] ); ?>
			</div>
			<div class="counter__content">
				<div <?php $this->print_render_attribute_string( 'counter_number' ); ?>>
					<?php echo esc_attr( $settings['number'] ); ?>
				</div>
				<<?php echo esc_html( $settings['title_size'] ); ?> <?php $this->print_render_attribute_string( 'title_css' ); ?>>
					<?php echo wp_kses_post( $settings['title'] ); ?>
				</<?php echo esc_html( $settings['title_size'] ); ?>>
			</div>
		</div>
		<?php
	}

	/**
	 * Render the Plain content.
	 */
	public function render_plain_content() {}
}


