<?php
namespace HellixElementor\Modules\TeamMember\Widgets;

use Elementor\Controls_Manager;
use Elementor\Core\Schemes;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Icons_Manager;
use Elementor\Utils;
use Elementor\Repeater;
use HellixElementor\Modules\TeamMember\Skins;
use HellixElementor\Base\Base_Widget;
use HellixElementor\Core\Utils as HXUtils;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
/**
 * Team Member Widget Class.
 */
class Team_Member extends Base_Widget {

	/**
	 * Get widget name.
	 *
	 * Retrieve button widget name.
	 *
	 * @since 1.0.0
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'hx-team-member';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve button widget title.
	 *
	 * @since 1.0.0
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Team Member', 'hellix-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve button widget icon.
	 *
	 * @since 1.0.0
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-user-circle-o';
	}

	/**
	 * Get the keywords associated with the widget.
	 *
	 * @return array
	 */
	public function get_keywords() {
		return [ 'team', 'member' ];
	}

	/**
	 * Register controls for this widget.
	 */
	protected function register_controls() {
		$this->team_member_general_controls_content_tab();
		$this->team_member_style_tab_controls();
	}

	/**
	 * Team member general controls content tab.
	 */
	public function team_member_general_controls_content_tab() {

		// General Content Tab Start.
		$this->start_controls_section(
			'section_general',
			[
				'label' => esc_html__( 'General', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'image',
			[
				'label'   => esc_html__( 'Choose Image', 'hellix-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'   => esc_html__( 'Name Tag', 'hellix-elementor' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'h2'   => 'H2',
					'h3'   => 'H3',
					'h4'   => 'H4',
					'h5'   => 'H5',
					'h6'   => 'H6',
					'span' => 'SPAN',
				],
				'default' => 'h5',
			]
		);

		$this->add_control(
			'title',
			[
				'label'   => esc_html__( 'Author Name', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( 'Author Name', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'position',
			[
				'label'   => esc_html__( 'Position', 'hellix-elementor' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( 'Position', 'hellix-elementor' ),
			]
		);

		$this->add_control(
			'show_social_icon',
			[
				'label'              => esc_html__( 'Show Author Social Icon?', 'hellix-elementor' ),
				'type'               => Controls_Manager::SWITCHER,
				'default'            => 'yes',
				'description'        => esc_html__( 'Enable to display author social icon.', 'hellix-elementor' ),
				'frontend_available' => true,
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'skin_icon_link',
			[
				'label'       => esc_html__( 'Social Icon Link', 'hellix-elementor' ),
				'type'        => Controls_Manager::URL,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'https://your-link.com', 'hellix-elementor' ),
				'default'     => [
					'url' => '#',
				],
			]
		);

		$repeater->add_control(
			'skin_selected_icon',
			[
				'label'            => esc_html__( 'Icon', 'hellix-elementor' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'skin_item_icon',
			]
		);

		$this->add_control(
			'skin_social_icon',
			[
				'label'       => esc_html__( 'Social Icons', 'hellix-elementor' ),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'condition'   => [
					'show_social_icon' => 'yes',

				],
				'default'     => [
					[
						'skin_selected_icon' => [
							'value' => 'fa fa-facebook',
						],
					],
					[

						'skin_selected_icon' => [
							'value' => 'fa fa-twitter',
						],
					],
					[

						'skin_selected_icon' => [
							'value' => 'fa fa-instagram',
						],
					],

				],

				'title_field' => '<# var migrated = "undefined" !== typeof __fa4_migrated, skin_item_icon = ( "undefined" === typeof skin_item_icon ) ? false : skin_item_icon; #>{{{ elementor.helpers.renderIcon( skin_selected_icon, skin_item_icon, true, migrated, true ) }}}',
			]
		);

		// General Content Tab End.
		$this->end_controls_section();
	}
	/**
	 * Team member style tab controls.
	 */
	public function team_member_style_tab_controls() {

		// Skin General Style Tab Start.
		$this->start_controls_section(
			'skin_general_style',
			[
				'label'      => esc_html__( 'General', 'hellix-elementor' ),
				'tab'        => Controls_Manager::TAB_STYLE,
				'show_label' => false,
			]
		);

		$this->add_control(
			'skin_title_color',
			[
				'label'     => esc_html__( 'Title Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hx-elementor-team-member-name' => 'color: {{VALUE}}',
				],
				'default'   => '#ffffff',
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'skin_title_typography',
				'selector' => '{{WRAPPER}} .hx-elementor-team-member-name',
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'skin_position_color',
			[
				'label'     => esc_html__( 'Postion Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hx-elementor-team-member-position' => 'color: {{VALUE}}',
				],
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'skin_position_typography',
				'selector' => '{{WRAPPER}} .hx-elementor-team-member-position',
				'scheme'   => Schemes\Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_control(
			'skin_social_icon_color',
			[
				'label'     => esc_html__( 'Social Icon Color', 'hellix-elementor' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hx-team-member-icon' => 'color: {{VALUE}}',
				],
				'default'   => '#ffffff',
				'separator' => 'before',
			]
		);

		$this->end_controls_section();

	}

	/**
	 * Render Team Member widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$link     = $settings['image']['url'];
		?>
		<div class="team -hover">
			<div data-anim="img-right cover-black" class="team__image">
				<?php echo wp_kses_post( HXUtils::render_bg_image( $link, '', '3:4' ) ); ?>
			</div>
			<div class="team__content">
			<?php if ( 'yes' === $settings['show_social_icon'] ) : ?>
				<div class="team__socials">
					<?php
					foreach ( $settings ['skin_social_icon'] as $index => $item ) {
						$migrated = isset( $item['__fa4_migrated']['skin_selected_icon'] );
						$is_new   = empty( $item['skin_item_icon'] ) && Icons_Manager::is_migration_allowed();
						$has_icon = ( ! $is_new || ! empty( $item['skin_selected_icon']['value'] ) );

						if ( $is_new || $migrated ) {
							?>
							<a data-barba href="<?php echo esc_attr( $item['skin_icon_link']['url'] ); ?>" class="hx-team-member-icon"><?php Icons_Manager::render_icon( $item['skin_selected_icon'] ); ?>
									</a>      
								<?php
						} else {
							?>
							<a data-barba href="<?php echo esc_attr( $item['skin_icon_link']['url'] ); ?>" class="hx-team-member-icon"><i class="<?php echo esc_attr( $item['skin_item_icon'] ); ?>" aria-hidden="true"></i>
							</a>
							<?php
						}
					}
					?>
				</div>
			<?php endif; ?>
			<?php if ( ! empty( $settings['title'] ) || ! empty( $settings['position'] ) ) : ?>      
				<div class="md:d-none">
					<?php if ( ! empty( $settings['position'] ) ) : ?>
					<div class="hx-elementor-team-member-position team__info">
						<?php echo wp_kses_post( $settings['position'] ); ?>
					</div> 
					<?php endif; ?>
					<?php if ( ! empty( $settings['title'] ) ) : ?>
					<<?php echo esc_attr( $settings['title_tag'] ); ?> class="hx-elementor-team-member-name team__title"><?php echo wp_kses_post( $settings['title'] ) . '</' . esc_attr( $settings['title_tag'] ); ?>>
					<?php endif; ?>
				</div>
			<?php endif; ?>
			</div>
		</div>
		<?php
	}
}
