<?php
/**
 * Plugin Name:     Hellix Extensions
 * Plugin URI:      https://themeforest.net/user/madrasthemes/portfolio
 * Description:     This selection of extensions compliment our theme Hellix. Please note: they don’t work with any WordPress theme, just Hellix.
 * Author:          MadrasThemes
 * Author URI:      https://madrasthemes.com/
 * Version:         1.0.0
 * Text Domain:     hellix-extensions
 * Domain Path:     /languages
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Define HELLIX_PLUGIN_FILE.
if ( ! defined( 'HELLIX_PLUGIN_FILE' ) ) {
	define( 'HELLIX_PLUGIN_FILE', __FILE__ );
}

if ( ! class_exists( 'Hellix_Extensions' ) ) {
	/**
	 * Main Hellix_Extensions Class
	 *
	 * @class Hellix_Extensions
	 * @version 1.0.0
	 * @since 1.0.0
	 * @package HellixExtensions
	 */
	final class Hellix_Extensions {

		/**
		 * Hellix_Extensions The single instance of Hellix_Extensions.
		 *
		 * @var     object
		 * @since   1.0.0
		 */
		private static $_instance = null;

		/**
		 * The token.
		 *
		 * @var     string
		 * @since   1.0.0
		 */
		public $token;

		/**
		 * The version number.
		 *
		 * @var     string
		 * @since   1.0.0
		 */
		public $version;

		/**
		 * Constructor function.
		 *
		 * @since   1.0.0
		 * @return  void
		 */
		public function __construct() {

			$this->token   = 'hellix-extensions';
			$this->version = '1.0.0';

			add_action( 'plugins_loaded', array( $this, 'setup_constants' ), 10 );
			add_action( 'plugins_loaded', array( $this, 'includes' ), 20 );
		}

		/**
		 * Main Hellix_Extensions Instance
		 *
		 * Ensures only one instance of Hellix_Extensions is loaded or can be loaded.
		 *
		 * @since 1.0.0
		 * @static
		 * @see Hellix_Extensions()
		 * @return Main Hellix instance
		 */
		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		/**
		 * Setup plugin constants
		 *
		 * @since  1.0.0
		 * @return void
		 */
		public function setup_constants() {

			// Plugin Folder Path.
			if ( ! defined( 'HELLIX_EXTENSIONS_DIR' ) ) {
				define( 'HELLIX_EXTENSIONS_DIR', plugin_dir_path( __FILE__ ) );
			}

			// Plugin Folder URL.
			if ( ! defined( 'HELLIX_EXTENSIONS_URL' ) ) {
				define( 'HELLIX_EXTENSIONS_URL', plugin_dir_url( __FILE__ ) );
			}

			// Plugin Root File.
			if ( ! defined( 'HELLIX_EXTENSIONS_FILE' ) ) {
				define( 'HELLIX_EXTENSIONS_FILE', __FILE__ );
			}

			// Modules File.
			if ( ! defined( 'HELLIX_EXTENSIONS_MODULES_DIR' ) ) {
				define( 'HELLIX_EXTENSIONS_MODULES_DIR', HELLIX_EXTENSIONS_DIR . '/modules' );
			}

			$this->define( 'HELLIX_ABSPATH', dirname( HELLIX_EXTENSIONS_FILE ) . '/' );
			$this->define( 'HELLIX_VERSION', $this->version );
		}

		/**
		 * Define constant if not already set.
		 *
		 * @param string      $name  Constant name.
		 * @param string|bool $value Constant value.
		 */
		private function define( $name, $value ) {
			if ( ! defined( $name ) ) {
				define( $name, $value );
			}
		}

		/**
		 * What type of request is this?
		 *
		 * @param  string $type admin, ajax, cron or hellixend.
		 * @return bool
		 */
		private function is_request( $type ) {
			switch ( $type ) {
				case 'admin':
					return is_admin();
				case 'ajax':
					return defined( 'DOING_AJAX' );
				case 'cron':
					return defined( 'DOING_CRON' );
				case 'hellixend':
					return ( ! is_admin() || defined( 'DOING_AJAX' ) ) && ! defined( 'DOING_CRON' ) && ! $this->is_rest_api_request();
			}
		}

		/**
		 * Include required files
		 *
		 * @since  1.0.0
		 * @return void
		 */
		public function includes() {
			/**
			 * Class autoloader.
			 */
			include_once HELLIX_EXTENSIONS_DIR . '/includes/class-hellix-autoloader.php';

			/**
			 * Core classes.
			 */
			require HELLIX_EXTENSIONS_DIR . '/includes/functions.php';

			/**
			 * Custom Post Types
			 */
			require HELLIX_EXTENSIONS_MODULES_DIR . '/portfolio/classes/class-hellix-jetpack-portfolio.php';

			if ( $this->is_request( 'admin' ) ) {
				include_once HELLIX_EXTENSIONS_DIR . '/includes/admin/class-hellix-admin.php';
			}
		}

		/**
		 * Get the plugin url.
		 *
		 * @return string
		 */
		public function plugin_url() {
			return untrailingslashit( plugins_url( '/', HELLIX_PLUGIN_FILE ) );
		}

		/**
		 * Cloning is forbidden.
		 *
		 * @since 1.0.0
		 */
		public function __clone() {
			_doing_it_wrong( __FUNCTION__, esc_html__( 'Cheatin&#8217; huh?', 'hellix-extensions' ), '1.0.0' );
		}

		/**
		 * Unserializing instances of this class is forbidden.
		 *
		 * @since 1.0.0
		 */
		public function __wakeup() {
			_doing_it_wrong( __FUNCTION__, esc_html__( 'Cheatin&#8217; huh?', 'hellix-extensions' ), '1.0.0' );
		}
	}
}

/**
 * Returns the main instance of Hellix_Extensions to prevent the need to use globals.
 *
 * @since  1.0.0
 * @return object Hellix_Extensions
 */
function Hellix_Extensions() { //phpcs:ignore WordPress.NamingConventions.ValidFunctionName.FunctionNameInvalid
	return Hellix_Extensions::instance();
}

/**
 * Initialise the plugin
 */
Hellix_Extensions();
