<?php
/**
 * Hellix Admin
 *
 * @class    hellix_Admin
 * @package  hellixExtensions/Admin
 * @version  1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Hellix_Admin class.
 */
class Hellix_Admin {

	/**
	 * Constructor.
	 */
	public function __construct() {
		add_action( 'init', array( $this, 'includes' ) );
		add_action( 'admin_init', array( $this, 'buffer' ), 1 );
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_styles' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_scripts' ) );

	}

	/**
	 * Output buffering allows admin screens to make redirects later on.
	 */
	public function buffer() {
		ob_start();
	}

	/**
	 * Include any classes we need within admin.
	 */
	public function includes() {
		include_once dirname( __FILE__ ) . '/hellix-meta-box-functions.php';
		include_once dirname( __FILE__ ) . '/class-hellix-admin-meta-boxes.php';
	}

	/**
	 * Enqueue style.
	 */
	public function admin_styles() {

		$screen    = get_current_screen();
		$screen_id = $screen ? $screen->id : '';

		if ( in_array( $screen_id, array( 'jetpack-portfolio' ) ) ) {

			wp_register_style( 'hellix_admin_styles', Hellix_Extensions()->plugin_url() . '/assets/css/admin/admin.css', array(), HELLIX_VERSION );
			wp_enqueue_style( 'hellix_admin_styles' );
		}
		wp_register_style( 'hellix_admin_styles', Hellix_Extensions()->plugin_url() . '/assets/css/admin/admin.css', array(), HELLIX_VERSION );
		wp_enqueue_style( 'hellix_admin_styles' );
	}

	/**
	 * Enqueue scripts.
	 */
	public function admin_scripts() {
		global $wp_query, $post;

		$screen          = get_current_screen();
		$screen_id       = $screen ? $screen->id : '';
		$front_screen_id = sanitize_title( __( 'Hellix', 'hellix-extensions' ) );
		$suffix          = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		if ( in_array( $screen_id, array( 'jetpack-portfolio' ) ) ) {
			wp_enqueue_media();
			wp_register_script( 'hellix-admin-portfolio-meta-boxes', Hellix_Extensions()->plugin_url() . '/assets/js/admin/meta-boxes-portfolio.js', array( 'jquery', 'jquery-ui-sortable', 'media-models' ), HELLIX_VERSION );
			wp_enqueue_script( 'hellix-admin-portfolio-meta-boxes' );
		}
	}
}

return new Hellix_Admin();
